# frozen_string_literal: true
require 'gdas/artifact_analyzers/asset_job_sets/one_product_job_set'
require 'gdas/artifact_analyzers/asset_job_sets/multi_product_job_set'

module Gdas::ArtifactAnalyzers::JobSets
  class AssetJobSetFactory
    # Creates a new AssetJobSet instance based off the given asset type, products present in the
    # artifact, and the products associated with the given asset type.
    #
    # If exactly one of the products associated with the given asset type is present in the bill,
    # the OneProductAssetJobSet implementation will be used, else the MultiProductAssetJobSet
    # will be used.
    #
    # Reference the descriptions for each implementation below for an explanation as to why there
    # are two different implementations.
    def self.new_asset_job_set(owner_account, asset_type, prods_present, asset_to_prods, partition_min, partition_max, partition_inc_func)
      associated_prods = asset_to_prods[asset_type].select { |prod| prods_present.include?(prod) }

      if associated_prods.size == 1
        OneProductAssetJobSet.new(owner_account, asset_type, associated_prods[0], partition_min, partition_max, partition_inc_func)
      else
        MultiProductAssetJobSet.new(owner_account, asset_type, associated_prods, partition_min, partition_max, partition_inc_func)
      end
    end
  end
end
