# frozen_string_literal: true
#
module Gdas::ArtifactAnalyzers::Azure

  class AzureXformAnalyzer < ::Gdas::ArtifactAnalyzers::XformAnalyzer
    class << self
      extend ::Memoist

      # Names of the x-form artifacts that this analyzer supports
      def supported_artifacts
        ['gdas_azure_artifact', 'azure_sql_data_warehouses', 'azure_sql_databases']
      end

      def required_columns
        super.merge(
          azure_account_id: 'AzureAccountId',
          cost_center: 'CostCenter',
          department_name: 'DepartmentName',
          resource_group: 'ResourceGroup'
        ).freeze
      end
      memoize :required_columns, :identifier => :azure_xform_analyzer

      def column_cloud_account_id
        'SubscriptionId'
      end

      def cloud_name
        Gdas::Clouds::AzureCloudConfig::CLOUD_NAME
      end

      def add_resource_data(resource_data, stream_adapter, row)
        resource_data[:azure_account_id] = stream_adapter.column_value_for_row(row, required_columns[:azure_account_id])
        resource_data[:cost_center] = stream_adapter.column_value_for_row(row, required_columns[:cost_center])
        resource_data[:department_name] = stream_adapter.column_value_for_row(row, required_columns[:department_name])
        resource_data[:resource_group] = stream_adapter.column_value_for_row(row, required_columns[:resource_group])
      end

      def update_resource_data(stored_resource, stream_adapter, row)
        add_resource_data(stored_resource, stream_adapter, row)
      end

    end
  end
end
