# frozen_string_literal: true

require 'gdas/assets/aws/alexa_for_business/context'

module Gdas::Assets::Aws::AlexaForBusiness
  module Devices
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'device'
      end

      # Resource ID format: arn:aws:a4b:us-east-1:account-id:device/a03aa47ffa1f71ce9e80b4765ae122ba/G090LF0964622CBP:A3S5BH2HU6VAYF
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Alexa for Business',
        resource_id_pattern: /(.*?):a4b:([^:]+):([[:digit:]]+):device\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsAlexaForBusinessDevice
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_alexa_for_business_devices(context)
    process_payload Gdas::Assets::Aws::AlexaForBusiness::Devices::DerivedProcessor.new, context
  end
end
# :nocov:
