# frozen_string_literal: true

require 'gdas/assets/aws/alexa_for_business/context'

module Gdas::Assets::Aws::AlexaForBusiness
  module Users
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'user'
      end

      # Resource ID format: arn:aws:a4b:us-east-1:010002469911:user/a03aa47ffa1f71ce9e80b4765ae122ba/email
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Alexa for Business',
        resource_id_pattern: /(.*?):a4b:([^:]+):([[:digit:]]+):user\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsAlexaForBusinessUser
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_alexa_for_business_users(context)
    process_payload Gdas::Assets::Aws::AlexaForBusiness::Users::DerivedProcessor.new, context
  end
end
# :nocov:
