# frozen_string_literal: true

require 'gdas/assets/aws/amplify/context'

module Gdas::Assets::Aws::Amplify
  module Apps
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'app'
      end

      # Resource ID format: arn:aws:amplify:us-east-1:account_id:apps/d1234567890/branches/production
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Amplify',
        resource_id_pattern: /(.*?):amplify:([^:]+):([[:digit:]]+):apps\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsAmplifyApp
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_amplify_apps(context)
    process_payload Gdas::Assets::Aws::Amplify::Apps::DerivedProcessor.new, context
  end
end
# :nocov:
