# frozen_string_literal: true

require 'gdas/assets/aws/api_gateway/context'

module Gdas::Assets::Aws::ApiGateway
  module Stages
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'stage'
      end

      # Resource ID format: arn:aws:apigateway:region::/restapis/gateway-id/stages/name
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon API Gateway',
        resource_id_pattern: /(.*?):apigateway:([^:]+)::\/restapis\/(.*)\/stages\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsApiGatewayStage
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_api_gateway_stages(context)
    process_payload Gdas::Assets::Aws::ApiGateway::Stages::DerivedProcessor.new, context
  end
end
# :nocov:
