# frozen_string_literal: true

require 'gdas/assets/aws/app_stream/context'

module Gdas::Assets::Aws::AppStream
  module Fleets
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'fleet'
      end

      # Resource ID format: arn:aws:appstream:region:account-id:fleet/Test_AppStream_Stack_Fleet
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon AppStream',
        resource_id_pattern: /(.*?):appstream:([^:]+):([[:digit:]]+):fleet\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsAppStreamFleet
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_app_stream_fleets(context)
    process_payload Gdas::Assets::Aws::AppStream::Fleets::DerivedProcessor.new, context
  end
end
# :nocov:
