# frozen_string_literal: true

require 'gdas/assets/aws/app_stream/context'

module Gdas::Assets::Aws::AppStream
  module ImageBuilders
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'image_builder'
      end

      # Resource ID format: arn:aws:appstream:eu-west-1:704291889205:image-builder/SmartConsoleBuilder
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon AppStream',
        resource_id_pattern: /(.*?):appstream:([^:]+):([[:digit:]]+):image-builder\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsAppStreamImageBuilder
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_app_stream_image_builders(context)
    process_payload Gdas::Assets::Aws::AppStream::ImageBuilders::DerivedProcessor.new, context
  end
end
# :nocov:
