# frozen_string_literal: true

require 'gdas/assets/aws/app_stream/context'

module Gdas::Assets::Aws::AppStream
  module Users
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'user'
      end

      # Resource ID format: arn:aws:appstream:region:account-id:user/userpool/00001111-2222-3333-4444-555566667777
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon AppStream',
        resource_id_pattern: /(.*?):appstream:([^:]+):([[:digit:]]+):user\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsAppStreamUser
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_app_stream_users(context)
    process_payload Gdas::Assets::Aws::AppStream::Users::DerivedProcessor.new, context
  end
end
# :nocov:
