# frozen_string_literal: true

require 'gdas/assets/aws/athena/context'

module Gdas::Assets::Aws::Athena
  module Workgroups
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'workgroup'
      end

      # Resource ID format: arn:aws:athena:region:account_id:workgroup/workgroup_name
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Athena',
        resource_id_pattern: /(.*?):athena:([^:]+):([[:digit:]]+):workgroup\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsAthenaWorkgroup
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_athena_workgroups(context)
    process_payload Gdas::Assets::Aws::Athena::Workgroups::DerivedProcessor.new, context
  end
end
# :nocov:
