# frozen_string_literal: true

require 'gdas/assets/aws/aurora/context'

module Gdas::Assets::Aws::Aurora
  module ClusterSnapshots
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'cluster_snapshot'
      end

      # This asset has 2 different format
      # Resource ID format: arn:aws:rds:region:account-id:cluster-backup:snapshot-id
      # Resource ID format: arn:aws:rds:region:account-id:cluster-snapshot:snapshot-id
      register_derived_collector(
          service: service,
          asset: asset,
          product_name: 'Amazon Relational Database Service',
          resource_id_pattern: /(.*?):rds:([^:]+):([[:digit:]]+):cluster-backup:(.*)|(.*?):rds:([^:]+):([[:digit:]]+):cluster-snapshot:(.*)/,
          format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsAuroraClusterSnapshot
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_aurora_cluster_snapshots(context)
    process_payload Gdas::Assets::Aws::Aurora::ClusterSnapshots::DerivedProcessor.new, context
  end
end
# :nocov:
