# frozen_string_literal: true

require 'gdas/assets/aws/bedrock/context'

module Gdas::Assets::Aws::Bedrock
  module Models
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'model'
      end

      # Resource ID format:
      # Foundation Model: arn:aws:bedrock:region::foundation-model/resource-id
      # Custom Model: arn:aws:bedrock:region:account-id:custom-model/resource-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_match_name: /.*Amazon Bedrock.*/,
        resource_id_pattern: /(.*?):bedrock:([^:]+):([^:]*):(.*)\-model\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsBedrockModel
    end
  end
end

if ImportRegistry.resolve('runtime').sandbox?
  def process_bedrock_models(context)
    process_payload Integrations::Aws::Assets::Bedrock::Models::DerivedProcessor.new, context
  end
end
