# frozen_string_literal: true

require 'gdas/assets/aws/chime/context'

module Gdas::Assets::Aws::Chime
  module Accounts
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'account'
      end

      # Resource ID format: 4d63d556-1405-4256-b27a-1403c04e201a
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Chime',
        resource_id_pattern: /^[0-9A-Fa-f]{8}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{12}$/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsChimeAccount
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_chime_accounts(context)
    process_payload Gdas::Assets::Aws::Chime::Accounts::DerivedProcessor.new, context
  end
end
# :nocov:
