# frozen_string_literal: true

require 'gdas/assets/aws/cloud_directory/context'

module Gdas::Assets::Aws::CloudDirectory
  module Directories
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      class << self
        def asset
          'directory'
        end
      end

      # Resource ID format: arn:aws:clouddirectory:region:account-id:directory/directoryID
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Cloud Directory',
        resource_id_pattern: /(.*?):clouddirectory:([^:]+):([[:digit:]]+):directory\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsCloudDirectoryDirectory
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_cloud_directory_directories(context)
    process_payload Gdas::Assets::Aws::CloudDirectory::Directories::DerivedProcessor.new, context
  end
end
# :nocov:
