# frozen_string_literal: true

require 'gdas/assets/aws/cloud_front/context'

module Gdas::Assets::Aws::CloudFront
  module Distributions
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'distribution'
      end

      # Resource ID format: arn:aws:cloudfront::146708650527:distribution/E3U4XXYWT2TBGO
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon CloudFront',
        resource_id_pattern: /(.*?):cloudfront::([[:digit:]]+):distribution\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :distribution_id
      )

      class << self
        def primary_identifier
          :distribution_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::CloudFrontDistribution
    end
  end
end
