# frozen_string_literal: true

require 'gdas/assets/aws/cloud_map/context'

module Gdas::Assets::Aws::CloudMap
  module Services
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'service'
      end

      # Resource ID format: arn:aws:servicediscovery:region:account-id:service/srv-000011112222aaaa/i-000011112222aaaab
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Cloud Map',
        resource_id_pattern: /(.*?):servicediscovery:([^:]+):([[:digit:]]+):service\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsCloudMapService
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_cloud_map_services(context)
    process_payload Gdas::Assets::Aws::CloudMap::Services::DerivedProcessor.new, context
  end
end
# :nocov:
