# frozen_string_literal: true

require 'gdas/assets/aws/cloud_search/context'

module Gdas::Assets::Aws::CloudSearch
  module Domains
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'domain'
      end

      # Resource ID format: arn:aws:cloudsearch:region:account-id:domain/search-test
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon CloudSearch',
        resource_id_pattern: /(.*?):cloudsearch:([^:]+):([[:digit:]]+):domain\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsCloudSearchDomain
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_cloud_search_domains(context)
    process_payload Gdas::Assets::Aws::CloudSearch::Domains::DerivedProcessor.new, context
  end
end
# :nocov:
