# frozen_string_literal: true

require 'gdas/assets/aws/cloudhsm/context'

module Gdas::Assets::Aws::Cloudhsm
  module Hsms
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'hsm'
      end

      # Resource ID format: arn:aws:cloudhsm:region:account-id:hsm/hsm-7gkfdjpxy5a
      # or arn:aws:cloudhsm:region:account-id:hsm-7gkfdjpxy5a
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS CloudHSM',
        resource_id_pattern: /(.*?):cloudhsm:([^:]+):([[:digit:]]+):hsm(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsCloudhsmHsm
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_cloudhsm_hsms(context)
    process_payload Gdas::Assets::Aws::Cloudhsm::Hsms::DerivedProcessor.new, context
  end
end
# :nocov:
