# frozen_string_literal: true

require 'gdas/assets/aws/cloudwatch_logs/context'

module Gdas::Assets::Aws::CloudwatchLogs
  module LogGroups
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'log_group'
      end

      # Resource ID format: arn:aws:logs:us-east-1:146708650527:log-group:/aws/rds/cluster/export-97-ec2-cluster/error
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AmazonCloudWatch',
        resource_id_pattern: /(.*?):logs:([^:]+):([[:digit:]]+):log-group:(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :log_group_name
      )

      class << self
        def primary_identifier
          :log_group_name
        end
      end


      def get_identifier(resource_id)
        resource_id.split(':').last
      end

      model ::AwsCloudwatchLogGroup
    end
  end
end
