# frozen_string_literal: true

require 'gdas/assets/aws/cm/context'

# Full product name: AWS Certificate Manager Certificate Authority
# 'Certificate Manager' abbr. to 'Cm' here for consistency with DB table name.
module Gdas::Assets::Aws::Cm
  module CertificateAuthorities
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'certificate_authority'
      end

      # Resource ID format: arn:aws:acm-pca:region:acct-id:certificate-authority/cert-auth-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Certificate Manager',
        resource_id_pattern: /(.*?):acm-pca:([^:]+):([[:digit:]]+):certificate-authority\/([a-f0-9\-]*)$/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsCmCertificateAuthority

      class << self
        # CM Certificate Authorities often only appear in the bill for the first hour of the month. Do not inactivate
        # until it does not appear at the beginning of the next month
        def gap_for_declaring_inactive
          # Number of hours in a month plus one.
          24 * 31 + 1
        end
      end
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_cm_certificate_authorities(context)
    process_payload Gdas::Assets::Aws::Cm::CertificateAuthorities::DerivedProcessor.new, context
  end
end
# :nocov:
