# frozen_string_literal: true

require 'gdas/assets/aws/cm/context'

# Full product name: AWS Certificate Manager Certificate
# 'Certificate Manager' abbr. to 'Cm' here for consistency with DB table name.
module Gdas::Assets::Aws::Cm
  module Certificates
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'certificate'
      end

      # Resource ID format:
      # arn:aws:acm:region:acct-id:certificate/cert-id
      # or:
      # arn:aws:acm-pca:region:acct-id:certificate-authority/ca-id/certificate/cert-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Certificate Manager',
        resource_id_pattern: /(.*?):acm(\-pca)?:([^:]+):([[:digit:]]+):(certificate-authority\/([a-f0-9\-]*)\/)?certificate\/([a-f0-9\-]*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsCmCertificate
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_cm_certificates(context)
    process_payload Gdas::Assets::Aws::Cm::Certificates::DerivedProcessor.new, context
  end
end
# :nocov:
