# frozen_string_literal: true

require 'gdas/assets/aws/code_build/context'

module Gdas::Assets::Aws::CodeBuild
  module Projects
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'project'
      end

      # Resource ID format: arn:aws:codebuild:region:account-id:project
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'CodeBuild',
        resource_id_pattern: /(.*?):codebuild:([^:]+):([[:digit:]]+):project\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsCodeBuildProject
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_code_build_projects(context)
    process_payload Gdas::Assets::Aws::CodeBuild::Projects::DerivedProcessor.new, context
  end
end
# :nocov:
