# frozen_string_literal: true

require 'gdas/assets/aws/cognito/context'

module Gdas::Assets::Aws::Cognito
  module UserPools
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'user_pool'
      end

      # Resource ID format: arn:aws:cognito-idp:us-east-1:192491131326:userpool/us-east-1_HcS03P4Gz
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Cognito',
        resource_id_pattern: /(.*?):cognito-idp:([^:]+):([[:digit:]]+):userpool\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsCognitoUserPool
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_cognito_user_pools(context)
    process_payload Gdas::Assets::Aws::Cognito::UserPools::DerivedProcessor.new, context
  end
end
# :nocov:
