# frozen_string_literal: true

require 'gdas/assets/aws/cost_management/context'

module Gdas::Assets::Aws::CostManagement
  module SavingsPlans
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'savings_plan'
      end

      # Resource ID format: arn:aws:savingsplans::146708650527:savingsplan/7dff3d6f-7902-426d-8e80-a047672bd897
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Savings Plans for AWS Compute usage',
        resource_id_pattern: /(.*?):savingsplans::([[:digit:]]+):savingsplan\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :savings_plan_id
      )

      class << self
        def primary_identifier
          :savings_plan_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsCostManagementSavingsPlan
    end
  end
end
