# frozen_string_literal: true

require 'gdas/assets/aws/data_exchange/context'

module Gdas::Assets::Aws::DataExchange
  module DataSets
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'data_set'
      end

      # Resource ID format: arn:aws:junto:region:account_id:data-sets/data-set_id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Data Exchange',
        resource_id_pattern: /(.*?):junto:([^:]+):([[:digit:]]+):data-sets\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsDataExchangeDataSet
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_data_exchange_data_sets(context)
    process_payload Gdas::Assets::Aws::DataExchange::DataSets::DerivedProcessor.new, context
  end
end
# :nocov:
