# frozen_string_literal: true

require 'gdas/assets/aws/data_pipeline/context'

module Gdas::Assets::Aws::DataPipeline
  module Pipelines
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'pipeline'
      end

      # Resource ID format: arn:aws:datapipeline:region:account-id:pipeline/pipeline-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Data Pipeline',
        resource_id_pattern: /(.*?):datapipeline:([^:]+):([[:digit:]]+):pipeline\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsDataPipelinePipeline
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_data_pipeline_pipelines(context)
    process_payload Gdas::Assets::Aws::DataPipeline::Pipelines::DerivedProcessor.new, context
  end
end
# :nocov:
