# frozen_string_literal: true

require 'gdas/assets/aws/datasync/context'

module Gdas::Assets::Aws::Datasync
  module Tasks
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'task'
      end

      # Resource ID formats:
      # arn:aws:sync:eu-west-1:account-id:task/task-id
      # arn:aws:datasync:eu-west-1:account-id:task/task-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS DataSync',
        resource_id_pattern: /(.*?):(?>data)?sync:([^:]+):([[:digit:]]+):task\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsDatasyncTask
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_datasync_tasks(context)
    process_payload Gdas::Assets::Aws::Datasync::Tasks::DerivedProcessor.new, context
  end
end
# :nocov:
