# frozen_string_literal: true

require 'gdas/assets/aws/directory_service/context'

module Gdas::Assets::Aws::DirectoryService
  module Directories
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      class << self
        def asset
          'directory'
        end

        # https://docs.aws.amazon.com/general/latest/gr/rande.html#ds_region
        def supported_govcloud_regions
          %w(us-gov-west-1).freeze
        end
      end

      # Resource ID format: arn:aws:ds:region:account-id:directory/directoryID
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Directory Service',
        resource_id_pattern: /(.*?):ds:([^:]+):([[:digit:]]+):directory\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsDirectoryServiceDirectory
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_directory_service_directories(context)
    process_payload Gdas::Assets::Aws::DirectoryService::Directories::DerivedProcessor.new, context
  end
end
# :nocov:
