# frozen_string_literal: true

require 'gdas/assets/aws/dms/context'

module Gdas::Assets::Aws::Dms
  module ReplicationInstances
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'replication_instance'
      end

      # Resource ID format: arn:aws:dms:us-west-2:651229300359:rep:MHKDV4CMQBRK4MUJ6ZQD4YDIESDOI5R5DQEKCOA
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Database Migration Service',
        resource_id_pattern: /(.*?):dms:([^:]+):([[:digit:]]+):rep:(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :replication_instance_arn
      )

      class << self
        def primary_identifier
          :replication_instance_arn
        end
      end


      def get_identifier(resource_id)
        resource_id
      end

      model ::AwsDmsReplicationInstance
    end
  end
end
