# frozen_string_literal: true

require 'gdas/assets/aws/document_db/context'

module Gdas::Assets::Aws::DocumentDb
  module Clusters
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'cluster'
      end

      # Resource ID format: arn:aws:rds:region:account-id:cluster:cluster-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon DocumentDB (with MongoDB compatibility)',
        resource_id_pattern: /(.*?):rds:([^:]+):([[:digit:]]+):cluster:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsDocumentDbCluster
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_document_db_clusters(context)
    process_payload Gdas::Assets::Aws::DocumentDb::Clusters::DerivedProcessor.new, context
  end
end
# :nocov:
