# frozen_string_literal: true

require 'gdas/assets/aws/document_db/context'

module Gdas::Assets::Aws::DocumentDb
  module Instances
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'instance'
      end

      # Resource ID format: arn:aws:rds:region:account-id:db:docdb-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon DocumentDB (with MongoDB compatibility)',
        resource_id_pattern: /(.*?):rds:([^:]+):([[:digit:]]+):db:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsDocumentDbInstance
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_document_db_instances(context)
    process_payload Gdas::Assets::Aws::DocumentDb::Instances::DerivedProcessor.new, context
  end
end
# :nocov:
