# frozen_string_literal: true

require 'gdas/assets/aws/dynamo_db/context'

module Gdas::Assets::Aws::DynamoDb
  module Backups
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'backup'
      end

      # Resource ID format: arn:aws:dynamodb:eu-west-1:12345678:table/classified-trackstat/backup/0123456789-af123
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon DynamoDB',
        resource_id_pattern: /(.*?):dynamodb:([^:]+):([[:digit:]]+):table\/(.*)\/backup\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsDynamoDbBackup
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_dynamo_db_backups(context)
    process_payload Gdas::Assets::Aws::DynamoDb::Backups::DerivedProcessor.new, context
  end
end
# :nocov:
