# frozen_string_literal: true

require 'gdas/assets/aws/dynamo_db/context'

module Gdas::Assets::Aws::DynamoDb
  module Tables
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'table'
      end

      # Resource ID format: arn:aws:dynamodb:us-east-1:924758434213:table/EmrFSMetadata
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon DynamoDB',
        resource_id_pattern: /(.*?):dynamodb:([^:]+):([[:digit:]]+):table\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :table_name
      )

      class << self
        def primary_identifier
          :table_name
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsDynamoDbTable
    end
  end
end
