# frozen_string_literal: true

require 'gdas/assets/aws/dynamo_db_accelerator/context'

module Gdas::Assets::Aws::DynamoDbAccelerator
  module Clusters
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'cluster'
      end

      # Resource ID format: arn:aws:dax:region:account-id:cache/cluster-name
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'DynamoDB Accelerator (DAX)',
        resource_id_pattern: /(.*?):dax:([^:]+):([[:digit:]]+):cache\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsDynamoDbAcceleratorCluster
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_dynamo_db_accelerator_clusters(context)
    process_payload Gdas::Assets::Aws::DynamoDbAccelerator::Clusters::DerivedProcessor.new, context
  end
end
# :nocov:
