# frozen_string_literal: true

require 'gdas/assets/aws/ec2/context'

module Gdas::Assets::Aws::Ec2
  module CapacityReservations
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'capacity_reservation'
      end

      # Resource ID format: arn:aws:ec2:region:account-id:capacity-reservation/cr-000011112222aaaab
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Elastic Compute Cloud',
        resource_id_pattern: /(.*?):ec2:([^:]+):([[:digit:]]+):capacity-reservation\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsEc2CapacityReservation
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_ec2_capacity_reservations(context)
    process_payload Gdas::Assets::Aws::Ec2::CapacityReservations::DerivedProcessor.new, context
  end
end
# :nocov:
