# frozen_string_literal: true

require 'gdas/assets/aws/ec2/context'

module Gdas::Assets::Aws::Ec2
  module DedicatedHosts
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'dedicated_host'
      end

      # Resource ID format: arn:aws:ec2:us-east-1:924758434213:dedicated-host/h-0929c85a0337fd413
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Elastic Compute Cloud',
        resource_id_pattern: /(.*?):ec2:([^:]+):([[:digit:]]+):dedicated-host\/h-(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :host_id
      )

      class << self
        def primary_identifier
          :host_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsDedicatedHost
    end
  end
end
