# frozen_string_literal: true

require 'gdas/assets/aws/ec2/context'

module Gdas::Assets::Aws::Ec2
  module NatGateways
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'nat_gateway'
      end

      # Resource ID format: arn:aws:ec2:us-east-1:773314406246:natgateway/nat-0d2cec60a9424f4aa
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Elastic Compute Cloud',
        resource_id_pattern: /(.*?):ec2:([^:]+):([[:digit:]]+):natgateway\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :nat_gateway_id
      )

      class << self
        def primary_identifier
          :nat_gateway_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsNatGateway
    end
  end
end
