# frozen_string_literal: true

require 'gdas/assets/aws/ec2/context'

module Gdas::Assets::Aws::Ec2
  module Snapshots
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      class << self
        def asset
          'snapshot'
        end

        def gdas_artifact_name
          'gdas_ec2_volumes_and_snapshots'
        end
      end

      # Resource ID format: arn:aws:ec2:us-east-1:773314406246:snapshot/snap-026adad531c2de95f
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Elastic Compute Cloud',
        resource_id_pattern: /(.*?):ec2:([^:]+):([[:digit:]]+):snapshot\/snap-(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :snapshot_id
      )

      class << self
        def primary_identifier
          :snapshot_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsSnapshot
    end
  end
end
