# frozen_string_literal: true

require 'gdas/assets/aws/ec2/context'

module Gdas::Assets::Aws::Ec2
  module Volumes
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      class << self
        def asset
          'volume'
        end

        def gdas_artifact_name
          'gdas_ec2_volumes_and_snapshots'
        end
      end

      # Resource ID format: vol-086839f7c1c2f4dfe
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Elastic Compute Cloud',
        resource_id_pattern: /vol-(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :volume_id
      )

      class << self
        def primary_identifier
          :volume_id
        end
      end


      def get_identifier(resource_id)
        resource_id
      end

      model ::AwsVolume
    end
  end
end
