# frozen_string_literal: true

require 'gdas/assets/aws/ecr/context'

module Gdas::Assets::Aws::Ecr
  module Repositories
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'repository'
      end

      # Resource ID format: arn:aws:ecr:us-east-1:012345678910:repository/misc
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon EC2 Container Registry (ECR)',
        resource_id_pattern: /(.*?):ecr:([^:]+):([[:digit:]]+):repository\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsEcrRepository
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_ecr_repositories(context)
    process_payload Gdas::Assets::Aws::Ecr::Repositories::DerivedProcessor.new, context
  end
end
# :nocov:
