# frozen_string_literal: true

require 'gdas/assets/aws/ecs/context'

module Gdas::Assets::Aws::Ecs
  module FargateTasks
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      class << self
        def asset
          'fargate_task'
        end

        def gdas_artifact_name
          'gdas_ecs_artifact_with_metadata'
        end

        def job_partition_column
          'SyntheticIdSha1'
        end

        def job_partition_field
          :synthetic_id_sha1
        end
      end

      # Resource ID format: arn:syn:ecs:FargateTask:account-id:region:id
      register_derived_collector(
          service: service,
          asset: asset,
          product_name: ['Amazon EC2 Container Service', 'Amazon Elastic Container Service'],
          resource_id_pattern: /arn:syn:ecs:FargateTask:([^:]+):([[:digit:]]+):(.*)/,
          format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )
      model ::AwsEcsFargateTask

      asset_identifiers(
          :aws_region_id,
          { db: :synthetic_id, dso: :resource_id },
          { db: :synthetic_id_sha1, sha_source: :resource_id } # The sha1 is used in a SQL index to help lookups.
      )

      def self.job_partition_field
        'synthetic_id_sha1'
      end
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_ecs_fargate_tasks(context)
    process_payload Gdas::Assets::Aws::Ecs::FargateTasks::DerivedProcessor.new, context
  end
end
# :nocov:
