# frozen_string_literal: true

require 'gdas/assets/aws/ec2/context'

module Gdas::Assets::Aws::EFS
  module ElasticFileSystems
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'elastic_file_system'
      end

      # Resource ID format: arn:aws:elasticfilesystem:eu-west-1:326050589688:file-system/fs-d057da1b
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Elastic File System',
        resource_id_pattern: /(.*?):elasticfilesystem:([^:]+):([[:digit:]]+):file-system\/fs-(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :file_system_id
      )

      class << self
        def primary_identifier
          :file_system_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsElasticFileSystem
    end
  end
end
