# frozen_string_literal: true

require 'gdas/assets/aws/eks/context'

module Gdas::Assets::Aws::Eks
  module Clusters
    # G-DAS C/P
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'cluster'
      end

      # Resource ID format: arn:aws:eks:us-west-2:012345678910:cluster/misc-eks
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Elastic Container Service for Kubernetes',
        resource_id_pattern: /(.*?):eks:([^:]+):([[:digit:]]+):cluster\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsEksCluster
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_derived_eks_clusters(context)
    process_payload Gdas::Assets::Aws::Eks::Clusters::DerivedProcessor.new, context
  end
end
# :nocov:
