# frozen_string_literal: true

require 'gdas/assets/aws/eks/context'

module Gdas::Assets::Aws::Eks
  module FargatePods
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'fargate_pod'
      end

      # Resource ID format: arn:aws:eks:region:account-id:pod
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Elastic Container Service for Kubernetes',
        resource_id_pattern: /(.*?):eks:([^:]+):([[:digit:]]+):pod\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsEksFargatePod
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_eks_fargate_pods(context)
    process_payload Gdas::Assets::Aws::Eks::FargatePods::DerivedProcessor.new, context
  end
end
# :nocov:
