# frozen_string_literal: true

require 'gdas/assets/aws/elasticache/context'

module Gdas::Assets::Aws::Elasticache
  module Clusters
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'cluster'
      end

      # Resource ID format: arn:aws:elasticache:us-east-1:146708650527:cluster:redis-web-002
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon ElastiCache',
        resource_id_pattern: /(.*?):elasticache:([^:]+):([[:digit:]]+):cluster:(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :name
      )

      class << self
        def primary_identifier
          :name
        end
      end


      def get_identifier(resource_id)
        resource_id.split(':').last
      end

      model ::AwsCacheCluster
    end
  end
end
