# frozen_string_literal: true

require 'gdas/assets/aws/elasticsearch/context'

module Gdas::Assets::Aws::Elasticsearch
  module Domains
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'domain'
      end

      # Resource ID format: arn:aws:es:us-east-1:146708650527:domain/container-cluster-11
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon OpenSearch Service',
        resource_id_pattern: /(.*?):es:([^:]+):([[:digit:]]+):domain\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :domain_id
      )

      class << self
        def primary_identifier
          :domain_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split(':')[4] + '/' + resource_id.split('/').last
      end

      model ::AwsElasticsearchDomain
    end
  end
end
