# frozen_string_literal: true

require 'gdas/assets/aws/elbv2/context'

module Gdas::Assets::Aws::ELBV2
  module ApplicationLoadBalancers
    # G-DAS C/P
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'application_load_balancer'
      end

      # Resource ID format: arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['Amazon Elastic Compute Cloud', 'Elastic Load Balancing'],
        resource_id_pattern: /(.*?):elasticloadbalancing:([^:]+):([[:digit:]]+):loadbalancer\/app\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsEc2ApplicationLoadBalancer
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_derived_ec2_application_load_balancers(context)
    process_payload Gdas::Assets::Aws::ELBV2::ApplicationLoadBalancers::DerivedProcessor.new, context
  end
end
# :nocov:
