# frozen_string_literal: true

require 'gdas/assets/aws/elemental_media_connect/context'

module Gdas::Assets::Aws::ElementalMediaConnect
  module Flows
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'flow'
      end

      # Resource ID format: arn:aws:mediaconnect:region:account_id:flow:resource_id:resource_name
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Elemental MediaConnect',
        resource_id_pattern: /(.*?):mediaconnect:([^:]+):([[:digit:]]+):flow:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsElementalMediaConnectFlow
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_elemental_media_connect_flows(context)
    process_payload Gdas::Assets::Aws::ElementalMediaConnect::Flows::DerivedProcessor.new, context
  end
end
# :nocov:
