# frozen_string_literal: true

require 'gdas/assets/aws/elemental_media_convert/context'

module Gdas::Assets::Aws::ElementalMediaConvert
  module Jobs
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'job'
      end

      # Resource ID format: arn:aws:mediaconvert:region:account-id:jobs
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Elemental MediaConvert',
        resource_id_pattern: /(.*?):mediaconvert:([^:]+):([[:digit:]]+):jobs\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsElementalMediaConvertJob
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_elemental_media_convert_jobs(context)
    process_payload Gdas::Assets::Aws::ElementalMediaConvert::Jobs::DerivedProcessor.new, context
  end
end
# :nocov:
