# frozen_string_literal: true

require 'gdas/assets/aws/elemental_media_live/context'

module Gdas::Assets::Aws::ElementalMediaLive
  module Inputs
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'input'
      end

      # Resource ID format: arn:aws:medialive:region-name:acct-id:input:input-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Elemental MediaLive',
        resource_id_pattern: /(.*?):medialive:([^:]+):([[:digit:]]+):input:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsElementalMediaLiveInput
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_elemental_media_live_inputs(context)
    process_payload Gdas::Assets::Aws::ElementalMediaLive::Inputs::DerivedProcessor.new, context
  end
end
# :nocov:
