# frozen_string_literal: true

require 'gdas/assets/aws/elemental_media_store/context'

module Gdas::Assets::Aws::ElementalMediaStore
  module Containers
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'container'
      end

      # Resource ID format: arn:aws:mediastore:us-east-1:012345678910:container/misc
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Elemental MediaStore',
        resource_id_pattern: /(.*?):mediastore:([^:]+):([[:digit:]]+):container\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsElementalMediaStoreContainer
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_elemental_media_store_containers(context)
    process_payload Gdas::Assets::Aws::ElementalMediaStore::Containers::DerivedProcessor.new, context
  end
end
# :nocov:
