# frozen_string_literal: true

require 'gdas/assets/aws/emr/context'

module Gdas::Assets::Aws::Emr
  module Clusters
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'clusters'
      end

      # Resource ID format: arn:aws:elasticmapreduce:us-east-1:146708650527:cluster/j-8IX9DDYTNGD9
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Elastic MapReduce',
        resource_id_pattern: /(.*?):elasticmapreduce:([^:]+):([[:digit:]]+):cluster\/j-(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :cluster_id
      )

      class << self
        def primary_identifier
          :cluster_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsEmrCluster
    end
  end
end
