# frozen_string_literal: true

require 'gdas/assets/aws/firewall_manager/context'

module Gdas::Assets::Aws::FirewallManager
  module Policies
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'policy'
      end

      # Resource ID format: arn:aws:fms:region:account_id:policy/policy_id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Firewall Manager',
        resource_id_pattern: /(.*?):fms:([^:]+):([[:digit:]]+):policy\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsFirewallManagerPolicy
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_firewall_manager_policies(context)
    process_payload Gdas::Assets::Aws::FirewallManager::Policies::DerivedProcessor.new, context
  end
end
# :nocov:
