# frozen_string_literal: true

require 'gdas/assets/aws/fsx/context'

module Gdas::Assets::Aws::Fsx
  module Backups
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'backup'
      end

      # Resource ID format: arn:aws:fsx:us-east-1:123456789012:backup/backup-123456789
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon FSx',
        resource_id_pattern: /(.*?):fsx:([^:]+):([[:digit:]]+):backup\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsFsxBackup
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_fsx_backups(context)
    process_payload Gdas::Assets::Aws::Fsx::Backups::DerivedProcessor.new, context
  end
end
# :nocov:
