# frozen_string_literal: true

require 'gdas/assets/aws/fsx/context'

module Gdas::Assets::Aws::Fsx
  module FileSystems
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'file_system'
      end

      # Resource ID format: arn:aws:fsx:eu-west-1:123456789012:file-system/fs-xyz123
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon FSx',
        resource_id_pattern: /(.*?):fsx:([^:]+):([[:digit:]]+):file-system\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsFsxFileSystem
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_fsx_file_systems(context)
    process_payload Gdas::Assets::Aws::Fsx::FileSystems::DerivedProcessor.new, context
  end
end
# :nocov:
