# frozen_string_literal: true

require 'gdas/assets/aws/gamelift/context'

module Gdas::Assets::Aws::Gamelift
  module Fleets
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'fleet'
      end

      # Resource ID format: arn:aws:gamelift:region:aws-account-id:fleet/fleet-00000000-1111-2222-3333-444455556666
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon GameLift',
        resource_id_pattern: /(.*?):gamelift:([^:]+):([[:digit:]]+):fleet\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsGameliftFleet
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_gamelift_fleets(context)
    process_payload Gdas::Assets::Aws::Gamelift::Fleets::DerivedProcessor.new, context
  end
end
# :nocov:
