# frozen_string_literal: true

require 'gdas/assets/aws/glacier/context'

module Gdas::Assets::Aws::Glacier
  module Vaults
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'vault'
      end

      # Resource ID format: arn:aws:glacier:region:account-id:vaults/vaultname
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Glacier',
        resource_id_pattern: /(.*?):glacier:([^:]+):([[:digit:]]+):vaults\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsGlacierVault
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_glacier_vaults(context)
    process_payload Gdas::Assets::Aws::Glacier::Vaults::DerivedProcessor.new, context
  end
end
# :nocov:
