# frozen_string_literal: true

require 'gdas/assets/aws/global_accelerator/context'

module Gdas::Assets::Aws::GlobalAccelerator
  module Accelerators
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'accelerator'
      end

      # Resource ID format: arn:aws:globalaccelerator::12345678:accelerator/a1111111-c111-2222-b222-c33333333333
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Global Accelerator',
        resource_id_pattern: /(.*?):globalaccelerator:(.*):([[:digit:]]+):accelerator\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsGlobalAcceleratorAccelerator
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_global_accelerator_accelerators(context)
    process_payload Gdas::Assets::Aws::GlobalAccelerator::Accelerators::DerivedProcessor.new, context
  end
end
# :nocov:
