# frozen_string_literal: true

require 'gdas/assets/aws/glue/context'

module Gdas::Assets::Aws::Glue
  module Crawlers
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'crawler'
      end

      # Resource ID format: uuid
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Glue',
        # Glue Crawlers have 2 different ResourceId formats:
        # - UUID: 00001111-2222-3333-4444-567890abcdef
        # - ARN: arn:aws:glue:us-east-1:000011112222:crawler/Crawler Name Here
        resource_id_pattern: /^(?:^(.*?):glue:([^:]+):([[:digit:]]+):crawler\/(.*)$)|(?:^[0-9A-Fa-f]{8}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{12}$)$/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsGlueCrawler
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_glue_crawlers(context)
    process_payload Gdas::Assets::Aws::Glue::Crawlers::DerivedProcessor.new, context
  end
end
# :nocov:
