# frozen_string_literal: true

require 'gdas/assets/aws/glue/context'

module Gdas::Assets::Aws::Glue
  module DevelopmentEndpoints
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'development_endpoint'
      end

      # Resource ID format: arn:aws:glue:region:account-id:devEndpoint/endpoint-name
      #                  OR any string
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Glue',
        # Resource IDs for this asset can either be an ARN or any string,
        # so we exclude formats for other Glue asset resource IDs.
        # Note: If we could match on additional columns of the DBR, the Operation would be helpful here. For
        # example, the Operation for the lines we've reviewed has always been +StartDevEndpoint+ for this
        # asset.
        resource_id_pattern: %r{
          ^
          (?!^ # Not any of these patterns:
            (?:[0-9A-Fa-f]{8}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{12}$)| # UUID - Crawler
            (?:jr_[0-9a-fA-F]+$)| # "jr_" - Job
            (?:(.*?):glue:([^:]+):([[:digit:]]+):(?:job|crawler)\/(.*)) # ARN with "job" or "crawler"
          $)
          .* # But anything else is acceptable.
          $
        }x,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsGlueDevelopmentEndpoint
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_glue_development_endpoints(context)
    process_payload Gdas::Assets::Aws::Glue::DevelopmentEndpoints::DerivedProcessor.new, context
  end
end
# :nocov:
