# frozen_string_literal: true

require 'gdas/assets/aws/glue/context'

module Gdas::Assets::Aws::Glue
  module Jobs
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'job'
      end

      # Resource ID format: arn:aws:glue:region:account-id:job/job-name
      #                  OR string beginning with "jr_"
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Glue',
        # Glue Jobs have either an ARN or a string starting with "jr_"
        # for a DBR resource id
        resource_id_pattern: /^(?:^(.*?):glue:([^:]+):([[:digit:]]+):job\/(.*)$)|(?:^jr_[0-9a-fA-F]+)$/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsGlueJob
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_glue_jobs(context)
    process_payload Gdas::Assets::Aws::Glue::Jobs::DerivedProcessor.new, context
  end
end
# :nocov:
