# frozen_string_literal: true

require 'gdas/assets/aws/greengrass/context'

module Gdas::Assets::Aws::Greengrass
  module Devices
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'device'
      end

      # Resource ID format: arn:aws:iot:us-west-2:account-id:thing/PitneyGroup_Core
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Greengrass',
        resource_id_pattern: /(.*?):iot:([^:]+):([[:digit:]]+):thing\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsGreengrassDevice
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_greengrass_devices(context)
    process_payload Gdas::Assets::Aws::Greengrass::Devices::DerivedProcessor.new, context
  end
end
# :nocov:
