# frozen_string_literal: true

require 'gdas/assets/aws/iot_1_click/context'

module Gdas::Assets::Aws::Iot1Click
  module Devices
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'device'
      end

      # Resource ID format: arn:aws:iot1click:us-west-2:141854384972:/devices/B9GHXT175100044
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS IoT 1 Click',
        resource_id_pattern: /(.*?):iot1click:([^:]+):([[:digit:]]+):devices\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsIot1ClickDevice
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_iot_1_click_devices(context)
    process_payload Gdas::Assets::Aws::Iot1Click::Devices::DerivedProcessor.new, context
  end
end
# :nocov:
