# frozen_string_literal: true

require 'gdas/assets/aws/iot_analytics/context'

module Gdas::Assets::Aws::IotAnalytics
  module Datastores
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'datastore'
      end

      # Resource ID format: arn:aws:iotanalytics:region:acct-id:datastore/datastore-name
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS IoT Analytics',
        resource_id_pattern: /(.*?):iotanalytics:([^:]+):([[:digit:]]+):datastore\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsIotAnalyticsDatastore
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_iot_analytics_datastores(context)
    process_payload Gdas::Assets::Aws::IotAnalytics::Datastores::DerivedProcessor.new, context
  end
end
# :nocov:
