# frozen_string_literal: true

require 'gdas/assets/aws/kendra/context'

module Gdas::Assets::Aws::Kendra
  module DataSources
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'data_source'
      end

      # Resource ID format: arn:aws:kendra:region:account-id:index/aaaabbbb-cccc-dddd-eeee-ffffaaaabbbb/data-source/aaaabbbb-cccc-dddd-eeee-ffffccccdddd
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Kendra',
        resource_id_pattern: /(.*?):kendra:([^:]+):([[:digit:]]+):index\/(.*)\/data-source\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsKendraDataSource
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_kendra_data_sources(context)
    process_payload Gdas::Assets::Aws::Kendra::DataSources::DerivedProcessor.new, context
  end
end
# :nocov:
