# frozen_string_literal: true

require 'gdas/assets/aws/kendra/context'

module Gdas::Assets::Aws::Kendra
  module Indices
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'index'
      end

      # Resource ID format: arn:aws:kendra:region:account-id:index/aaaabbbb-cccc-dddd-eeee-ffffaaaabbbb
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Kendra',
        resource_id_pattern: /^(.*?):kendra:([^:]+):([[:digit:]]+):index\/[0-9A-Fa-f]{8}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{12}$/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsKendraIndex
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_kendra_indices(context)
    process_payload Gdas::Assets::Aws::Kendra::Indices::DerivedProcessor.new, context
  end
end
# :nocov:
