# frozen_string_literal: true

require 'gdas/assets/aws/kinesis/context'

module Gdas::Assets::Aws::Kinesis
  module Streams
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'kinesis_streams'
      end

      # Resource ID format: arn:aws:kinesis:us-east-1:169315200093:stream/entity-delta-stream
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Kinesis',
        resource_id_pattern: /(.*?):kinesis:([^:]+):([[:digit:]]+):stream\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :name
      )

      class << self
        def primary_identifier
          :name
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsKinesisStream
    end
  end
end
