# frozen_string_literal: true

require 'gdas/assets/aws/kinesis/context'

module Gdas::Assets::Aws::Kinesis
  module VideoStreams
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'video_stream'
      end

      # Resource ID format: arn:aws:kinesisvideo:region:account-id:stream/stream-name/code
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Kinesis Video Streams',
        resource_id_pattern: /(.*?):kinesisvideo:([^:]+):([[:digit:]]+):stream\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsKinesisVideoStream
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_kinesis_video_streams(context)
    process_payload Gdas::Assets::Aws::Kinesis::VideoStreams::DerivedProcessor.new, context
  end
end
# :nocov:
