# frozen_string_literal: true

require 'gdas/assets/aws/kinesis_analytics/context'

module Gdas::Assets::Aws::KinesisAnalytics
  module Applications
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'application'
      end

      # Resource ID format: arn:aws:kinesisanalytics:region:account-id:application/system-test-results
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Kinesis Analytics',
        resource_id_pattern: /(.*?):kinesisanalytics:([^:]+):([[:digit:]]+):application\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsKinesisAnalyticsApplication
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_kinesis_analytics_applications(context)
    process_payload Gdas::Assets::Aws::KinesisAnalytics::Applications::DerivedProcessor.new, context
  end
end
# :nocov:
