# frozen_string_literal: true

require 'gdas/assets/aws/kinesis_firehose/context'

module Gdas::Assets::Aws::KinesisFirehose
  module Firehoses
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'kinesis_firehose'
      end

      # Resource ID format: arn:aws:firehose:us-east-1:146708650527:deliverystream/cht-ecs-event-stream
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Kinesis Firehose',
        resource_id_pattern: /(.*?):firehose:([^:]+):([[:digit:]]+):deliverystream\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :delivery_stream_name
      )

      class << self
        def primary_identifier
          :delivery_stream_name
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsKinesisFirehose
    end
  end
end
