# frozen_string_literal: true

require 'gdas/assets/aws/kms/context'

module Gdas::Assets::Aws::KMS
  module CMK
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'cmk'
      end

      # Resource ID format: arn:aws:kms:us-east-1:214848089233:key/1c247e5f-5e9c-4d89-9076-fecded00dd4f
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Key Management Service',
        resource_id_pattern: /(.*?):kms:([^:]+):([[:digit:]]+):key\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :key_id
      )

      class << self
        def primary_identifier
          :key_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsKmsCmk
    end
  end
end
