# frozen_string_literal: true

require 'gdas/assets/aws/lambda/context'

module Gdas::Assets::Aws::Lambda
  module Functions
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'functions'
      end

      # Resource ID format: arn:aws:lambda:us-east-1:146708650527:function:cw_queue_stats
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Lambda',
        resource_id_pattern: /(.*?):lambda:([^:]+):([[:digit:]]+):function:(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :function_arn,
      )

      class << self
        def primary_identifier
          :function_arn
        end
      end


      def get_identifier(resource_id)
        resource_id
      end

      model ::AwsLambdaFunction
    end
  end
end
