# frozen_string_literal: true

require 'gdas/assets/aws/lex/context'

module Gdas::Assets::Aws::Lex
  module Bots
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'bot'
      end

      # Resource ID format: :Linked-Account_Id/WebUiOrderFlowers/$LATEST
      # Resource ID format: arn:aws:lex:region:account-id:bot:
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Lex',
        resource_id_pattern: /.*?\/.*?\/.*|(.*?):lex:([^:]+):([[:digit:]]+):bot:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsLexBot
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_lex_bots(context)
    process_payload Gdas::Assets::Aws::Lex::Bots::DerivedProcessor.new, context
  end
end
# :nocov:
