# frozen_string_literal: true

require 'gdas/assets/aws/machine_learning/context'

module Gdas::Assets::Aws::MachineLearning
  module MlModels
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'ml_model'
      end

      # Resource ID format: arn:aws:machinelearning:region:acct-id:mlmodel/ml-4coRxQGyQlZ
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Machine Learning',
        resource_id_pattern: /(.*?):machinelearning:([^:]+):([[:digit:]]+):mlmodel\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsMachineLearningMlModel
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_machine_learning_ml_models(context)
    process_payload Gdas::Assets::Aws::MachineLearning::MlModels::DerivedProcessor.new, context
  end
end
# :nocov:
