# frozen_string_literal: true

require 'gdas/assets/aws/managed_blockchain/context'

module Gdas::Assets::Aws::ManagedBlockchain
  module Members
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'member'
      end

      # Resource ID format: arn:aws:managedblockchain:region:account-id:members/m-000011112222aaaabbbbccccdd
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Managed Blockchain',
        resource_id_pattern: /(.*?):managedblockchain:([^:]+):([[:digit:]]+):members\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsManagedBlockchainMember
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_managed_blockchain_members(context)
    process_payload Gdas::Assets::Aws::ManagedBlockchain::Members::DerivedProcessor.new, context
  end
end
# :nocov:
