# frozen_string_literal: true

require 'gdas/assets/aws/mq/context'

module Gdas::Assets::Aws::Mq
  module Brokers
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'broker'
      end

      # Resource ID format: arn:aws:mq:region:account-id:broker:broker_name:b-{broker_uuid}
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon MQ',
        resource_id_pattern: /(.*?):mq:([^:]+):([[:digit:]]+):broker:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsMqBroker
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_mq_brokers(context)
    process_payload Gdas::Assets::Aws::Mq::Brokers::DerivedProcessor.new, context
  end
end
# :nocov:
