# frozen_string_literal: true

require 'gdas/assets/aws/msk/context'

module Gdas::Assets::Aws::Msk
  module Clusters
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'cluster'
      end

      # Resource ID format: arn:aws:kafka:us-east-1:012345678910:cluster/wdpr-ra-msk-test/misc
      register_derived_collector(
        service: service,
        asset: asset,
        product_name:
          ['Amazon Managed Streaming for Kafka (MSK)', 'Amazon Managed Streaming for Apache Kafka'],
        resource_id_pattern: /(.*?):kafka:([^:]+):([[:digit:]]+):cluster\/(.*)\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsMskCluster
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_msk_clusters(context)
    process_payload Gdas::Assets::Aws::Msk::Clusters::DerivedProcessor.new, context
  end
end
# :nocov:
