# frozen_string_literal: true

require 'gdas/assets/aws/neptune/context'

module Gdas::Assets::Aws::Neptune
  module Clusters
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'cluster'
      end

      # Resource ID format: arn:aws:rds:us-east-2:012345678910:cluster:cluster-misc
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Neptune',
        resource_id_pattern: /(.*?):rds:([^:]+):([[:digit:]]+):cluster:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsNeptuneCluster
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_neptune_clusters(context)
    process_payload Gdas::Assets::Aws::Neptune::Clusters::DerivedProcessor.new, context
  end
end
# :nocov:
