# frozen_string_literal: true

require 'gdas/assets/aws/neptune/context'

module Gdas::Assets::Aws::Neptune
  module Instances
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'instance'
      end

      # Resource ID format: arn:aws:rds:us-east-2:012345678910:db:ec2-resource
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Neptune',
        resource_id_pattern: /(.*?):rds:([^:]+):([[:digit:]]+):db:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsNeptuneInstance
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_neptune_instances(context)
    process_payload Gdas::Assets::Aws::Neptune::Instances::DerivedProcessor.new, context
  end
end
# :nocov:
