# frozen_string_literal: true

require 'gdas/assets/aws/opsworks/context'

module Gdas::Assets::Aws::Opsworks
  module Servers
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'server'
      end

      # Resource ID format: arn:aws:opsworks-cm:region:aws-account-id:server/ServerName/00000000-1111-2222-3333-444455556666
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS OpsWorks',
        resource_id_pattern: /(.*?):opsworks-cm:([^:]+):([[:digit:]]+):server\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsOpsworksServer
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_opsworks_servers(context)
    process_payload Gdas::Assets::Aws::Opsworks::Servers::DerivedProcessor.new, context
  end
end
# :nocov:
