# frozen_string_literal: true

require 'gdas/assets/aws/pinpoint/context'

module Gdas::Assets::Aws::Pinpoint
  module Apps
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'app'
      end

      # Resource ID format: arn:aws:mobiletargeting:us-east-1:012345678910:apps/data
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Pinpoint',
        resource_id_pattern: /(.*?):mobiletargeting:([^:]+):([[:digit:]]+):apps\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsPinpointApp
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_pinpoint_apps(context)
    process_payload Gdas::Assets::Aws::Pinpoint::Apps::DerivedProcessor.new, context
  end
end
# :nocov:
