# frozen_string_literal: true

require 'gdas/assets/aws/quicksight/context'

module Gdas::Assets::Aws::Quicksight
  module Users
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'user'
      end

      # This assets has 4 different formats. We are using a set of 4 or-ed (|) regex expressions.
      # Resource ID format: arn:aws:ds:region:12345678:user/d-1234554321/12345678-1234-123f-123a-123456789012
      # Resource ID format: arn:aws:iam::12345678:user/xxxxxxx
      # Resource ID format: arn:aws:sts::123456768:assumed-role/QuickSight_Reader/xxxx@example.com
      # Resource ID format: arn:aws:quicksight:us-east-2:111122223333:user/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon QuickSight',
        resource_id_pattern: /(.*?):sts::([[:digit:]]+):assumed-role\/(.*)|(.*?):ds:([^:]+):([[:digit:]]+):user\/(.*)|(.*?):iam::([[:digit:]]+):user\/(.*)|(.*?):quicksight:([^:]+):([[:digit:]]+):user\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsQuicksightUser
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_quicksight_users(context)
    process_payload Gdas::Assets::Aws::Quicksight::Users::DerivedProcessor.new, context
  end
end
# :nocov:
