# frozen_string_literal: true

require 'gdas/assets/aws/rds/context'

module Gdas::Assets::Aws::RDS
  module Reservations
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'reservations'
      end

      # Resource ID format: arn:aws:rds:us-east-1:429538831549:ri:ri-2022-03-18-17-10-23-579
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['Amazon Relational Database Service', 'Amazon RDS Service'],
        resource_id_pattern: /(.*?):rds:([^:]+):([[:digit:]]+):ri:(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :instance_id
      )

      class << self
        def primary_identifier
          :instance_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split(':').last
      end

      model ::AwsRdsInstanceReservation
    end
  end
end