# frozen_string_literal: true

require 'gdas/assets/aws/redshift/context'

module Gdas::Assets::Aws::Redshift
  module Clusters
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'cluster'
      end

      # Resource ID format: arn:aws:redshift:us-east-1:924758434213:cluster:svc-mdr-holodeck
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Redshift',
        resource_id_pattern: /(.*?):redshift:([^:]+):([[:digit:]]+):cluster:(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :cluster_identifier
      )

      class << self
        def primary_identifier
          :cluster_identifier
        end
      end


      def get_identifier(resource_id)
        resource_id.split(':').last
      end

      model ::AwsRedshiftCluster
    end
  end
end
