# frozen_string_literal: true

require 'gdas/assets/aws/route53/context'

module Gdas::Assets::Aws::Route53
  module HealthChecks
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'health_check'
      end

      # Resource ID format: arn:aws:route53:::healthcheck/health-check-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Route 53',
        resource_id_pattern: /(.*?):route53:::healthcheck\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsRoute53HealthCheck
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_route53_health_checks(context)
    process_payload Gdas::Assets::Aws::Route53::HealthChecks::DerivedProcessor.new, context
  end
end
# :nocov:
