# frozen_string_literal: true

require 'gdas/assets/aws/route53/context'

module Gdas::Assets::Aws::Route53
  module HostedZones
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'hosted_zone'
      end

      # Resource ID format: arn:aws:route53:::hostedzone/Z2IWR8SMQNI29O
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Route 53',
        resource_id_pattern: /(.*?):route53:::hostedzone\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :hosted_zone_id
      )

      class << self
        def primary_identifier
          :hosted_zone_id
        end
      end


      def get_identifier(resource_id)
        "/hostedzone/" + resource_id.split('/').last
      end

      model ::AwsRoute53HostedZone
    end
  end
end
