# frozen_string_literal: true

require 'gdas/assets/aws/sage_maker/context'

module Gdas::Assets::Aws::SageMaker
  module BatchTransformJobs
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'batch_transform_job'
      end

      # Resource ID format: arn:aws:sagemaker:region:account-id:transform-job/transform-job-name
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon SageMaker',
        resource_id_pattern: /(.*?):sagemaker:([^:]+):([[:digit:]]+):transform-job\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsSageMakerBatchTransformJob
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_sage_maker_batch_transform_jobs(context)
    process_payload Gdas::Assets::Aws::SageMaker::BatchTransformJobs::DerivedProcessor.new, context
  end
end
# :nocov:
