# frozen_string_literal: true

require 'gdas/assets/aws/sage_maker/context'

module Gdas::Assets::Aws::SageMaker
  module Endpoints
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'endpoint'
      end

      # Resource ID format: arn:aws:sagemaker:us-west-2:604080085267:endpoint/31e7afa2-7e6e-40c3-bdcb-c753be884518
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon SageMaker',
        resource_id_pattern: /(.*?):sagemaker:([^:]+):([[:digit:]]+):endpoint\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :endpoint_name
      )

      class << self
        def primary_identifier
          :endpoint_name
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsSageMakerEndpoint
    end
  end
end
