# frozen_string_literal: true

require 'gdas/assets/aws/sage_maker/context'

module Gdas::Assets::Aws::SageMaker
  module NotebookInstances
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'notebook_instance'
      end

      # Resource ID format: arn:aws:sagemaker:us-east-1:146708650527:notebook-instance/vkp-time-series
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon SageMaker',
        resource_id_pattern: /(.*?):sagemaker:([^:]+):([[:digit:]]+):notebook-instance\/(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :notebook_instance_name
      )

      class << self
        def primary_identifier
          :notebook_instance_name
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsSagemakerNotebookInstance
    end
  end
end
