# frozen_string_literal: true

require 'gdas/assets/aws/sage_maker/context'

module Gdas::Assets::Aws::SageMaker
  module StudioNotebooks
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'studio_notebook'
      end

      # Resource ID format: arn:aws:sagemaker:region:account-id:app/instance-id/user-name/KernelGateway/kernel-name
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon SageMaker',
        resource_id_pattern: /(.*?):sagemaker:([^:]+):([[:digit:]]+):app\/(.*)\/(.*)\/(?i)KernelGateway\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsSageMakerStudioNotebook
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_sage_maker_studio_notebooks(context)
    process_payload Gdas::Assets::Aws::SageMaker::StudioNotebooks::DerivedProcessor.new, context
  end
end
# :nocov:
