# frozen_string_literal: true

require 'gdas/assets/aws/secrets_manager/context'

module Gdas::Assets::Aws::SecretsManager
  module Secrets
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'secret'
      end

      # Resource ID format: arn:aws:secretsmanager:region:account-id:secret:tst/maa/jwt-secret-UXDUXO
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Secrets Manager',
        resource_id_pattern: /(.*?):secretsmanager:([^:]+):([[:digit:]]+):secret:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsSecretsManagerSecret
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_secrets_manager_secrets(context)
    process_payload Gdas::Assets::Aws::SecretsManager::Secrets::DerivedProcessor.new, context
  end
end
# :nocov:
