# frozen_string_literal: true

require 'gdas/assets/aws/security_hub/context'

module Gdas::Assets::Aws::SecurityHub
  module Hubs
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'hub'
      end

      # Resource ID format: arn:aws:securityhub:region:account-id:hub/default
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Security Hub',
        resource_id_pattern: /(.*?):securityhub:([^:]+):([[:digit:]]+):hub\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsSecurityHubHub
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_security_hub_hubs(context)
    process_payload Gdas::Assets::Aws::SecurityHub::Hubs::DerivedProcessor.new, context
  end
end
# :nocov:
