# frozen_string_literal: true

require 'gdas/assets/aws/security_lake/context'

module Gdas::Assets::Aws::SecurityLake
  module DataLakes
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'data_lake'
      end

      # Resource ID format: arn:aws:securitylake:us-east-1:3367254377911:data-lake/default
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Security Lake',
        resource_id_pattern: /(.*?):securitylake:([^:]+):([[:digit:]]+):data-lake\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )
      
      model ::AwsSecurityLakeDataLake

      def custom_fields
        {
          data_lake_arn: -> (asset, dso, job_options) { dso[:resource_id] },
        }
      end

      class << self

        def resource_id_sha1_source_field
          :data_lake_arn
        end
      end

    end
  end
end

if ImportRegistry.resolve('runtime').sandbox?
  def process_security_lake_data_lake(context)
    process_payload Integrations::Aws::Assets::SecurityLake::DataLakes::DerivedProcessor.new, context
  end
end
