# frozen_string_literal: true

require 'gdas/assets/aws/shield/context'

module Gdas::Assets::Aws::Shield
  module Protections
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'protection'
      end

      # Resource ID format: arn:aws:shield:region:account-id:Protection/random-12345678
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Shield',
        resource_id_pattern: /(.*?):shield:([^:]+):([[:digit:]]+):Protection\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsShieldProtection
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_shield_protections(context)
    process_payload Gdas::Assets::Aws::Shield::Protections::DerivedProcessor.new, context
  end
end
# :nocov:
