# frozen_string_literal: true

require 'gdas/assets/aws/simple_email_service/context'

module Gdas::Assets::Aws::SimpleEmailService
  module DedicatedIps
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'dedicated_ip'
      end

      # Resource ID format: IP address in the form of: 000.000.000.000
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Simple Email Service',
        resource_id_pattern: /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsSimpleEmailServiceDedicatedIp
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_simple_email_service_dedicated_ips(context)
    process_payload Gdas::Assets::Aws::SimpleEmailService::DedicatedIps::DerivedProcessor.new, context
  end
end
# :nocov:
