# frozen_string_literal: true

require 'gdas/assets/aws/snowball/context'

module Gdas::Assets::Aws::Snowball
  module Jobs
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'job'
      end

      # Resource ID format: JID01234567-89ab-cdef-0123-456789abcdef
      # OR arn:aws:snowball:region:acct-id:JobResourceId/JID01234567-89ab-cdef-0123-456789abcdef
      # Some Snowball charges use the Job ID format while others use the ARN format.
      # We can match on both using just the Job ID, because it is included in the ARN.
      register_derived_collector(
        service: service,
        asset: asset,
        # 'AWS Snowball Extra Days' is an add'l product name for this service.
        # We don't need to worry about it in terms of asset derivation because
        # ALL Snowball assets will have 'AWS Import/Export Snowball' charges.
        # Only some will have 'AWS Snowball Extra Days' charges.
        product_name: 'AWS Import/Export Snowball',
        resource_id_pattern:
          # Match on beginning of line for Job ID or on forward slash for ARN.
          /(^|\/)JID[0-9A-Fa-f]{8}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{4}-[0-9A-Fa-f]{12}$/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsSnowballJob
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_snowball_jobs(context)
    process_payload Gdas::Assets::Aws::Snowball::Jobs::DerivedProcessor.new, context
  end
end
# :nocov:
