# frozen_string_literal: true

require 'gdas/assets/aws/sns/context'

module Gdas::Assets::Aws::Sns
  module Topics
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'topics'
      end

      # Resource ID format: arn:aws:sns:us-east-2:560353538958:cloudcoreo-events
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Simple Notification Service',
        resource_id_pattern: /(.*?):sns:([^:]+):([[:digit:]]+):(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :aws_region_id,
        :topic_name
      )

      class << self
        def primary_identifier
          :topic_name
        end
      end


      def get_identifier(resource_id)
        resource_id.split(':').last
      end

      model ::AwsSnsTopic
    end
  end
end
