# frozen_string_literal: true

require 'gdas/assets/aws/sqs/context'

module Gdas::Assets::Aws::Sqs
  module Queues
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'queue'
      end

      # Resource ID format: arn:aws:sqs:us-east-1:844584796563:corban-sqs-std-test-1
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Simple Queue Service',
        # regex isn't required for this asset, but it's included to validate the system.
        resource_id_pattern: /(.*?):sqs:([^:]+):([[:digit:]]+):(.*)/,
        # format: 1 # Format isn't required for this asset; it's defaulted to 1.
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsSqsQueue

      class << self
        # SQS queues could potentially not incur any cost if they are not used.
        # The plan is that we will not inactivate assets for at least a full
        # month.
        def gap_for_declaring_inactive
          # Number of hours in a month plus one.
          24 * 31 + 1
        end
      end
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_sqs_queues(context)
    process_payload Gdas::Assets::Aws::Sqs::Queues::DerivedProcessor.new, context
  end
end
# :nocov:
