# frozen_string_literal: true

require 'gdas/assets/aws/step_functions/context'

module Gdas::Assets::Aws::StepFunctions
  module StateMachines
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'state_machine'
      end

      # Resource ID format: arn:aws:states:us-west-2:123456789012:stateMachine:blahblah
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Step Functions',
        resource_id_pattern: /(.*?):states:([^:]+):([[:digit:]]+):stateMachine:(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      # Temporarily overriding `asset_identifiers` and removing `aws_region_id` for assets having
      # duplicate key insert errors due to region mismatch
      asset_identifiers(
        :resource_id,
        { db: :resource_id_sha1, sha_source: :resource_id }
      )

      model ::AwsStepFunctionsStateMachine
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_step_functions_state_machines(context)
    process_payload Gdas::Assets::Aws::StepFunctions::StateMachines::DerivedProcessor.new, context
  end
end
# :nocov:
