# frozen_string_literal: true

require 'gdas/assets/aws/storage_gateway/context'

module Gdas::Assets::Aws::StorageGateway
  module Tapes
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      class << self
        def asset
          'tape'
        end

        # https://docs.aws.amazon.com/general/latest/gr/rande.html#sg_region
        def supported_govcloud_regions
          %w(us-gov-west-1).freeze
        end
      end

      # Resource ID format: arn:aws:storagegateway:region:acct-id:tape/tape-id
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS Storage Gateway',
        resource_id_pattern: /(.*?):storagegateway:([^:]+):([[:digit:]]+):tape\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsStorageGatewayTape
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_storage_gateway_tapes(context)
    process_payload Gdas::Assets::Aws::StorageGateway::Tapes::DerivedProcessor.new, context
  end
end
# :nocov:
