# frozen_string_literal: true

require 'gdas/assets/aws/sumerian/context'

module Gdas::Assets::Aws::Sumerian
  module Binaries
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'binary'
      end

      # Resource ID format: arn:aws:sumerian:region:account:binaries/binary-name
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Sumerian',
        resource_id_pattern: /(.*?):sumerian:([^:]+):([[:digit:]]+):binaries\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsSumerianBinary
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_sumerian_binaries(context)
    process_payload Gdas::Assets::Aws::Sumerian::Binaries::DerivedProcessor.new, context
  end
end
# :nocov:
