# frozen_string_literal: true

require 'gdas/assets/aws/transcribe/context'

module Gdas::Assets::Aws::Transcribe
  module TranscriptionJobs
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'transcription_job'
      end

      # Resource ID format: arn:aws:transcribe:region:account-id:transcription-job/job-name
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Transcribe',
        resource_id_pattern: /(.*?):transcribe:([^:]+):([[:digit:]]+):transcription-job\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsTranscribeTranscriptionJob
    end
  end
end

if ImportRegistry.resolve('runtime').sandbox?
  def process_transcribe_transcription_jobs(context)
    process_payload Gdas::Assets::Aws::Transcribe::TranscriptionJobs::DerivedProcessor.new, context
  end
end
