# frozen_string_literal: true

require 'gdas/assets/aws/transfer_for_sftp/context'

module Gdas::Assets::Aws::TransferForSftp
  module Servers
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'server'
      end

      # Resource ID format: arn:aws:transfer:region:account-id:server/s-000011112222aaaab
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['AWS Transfer for SFTP', 'AWS Transfer Family'],
        resource_id_pattern: /(.*?):transfer:([^:]+):([[:digit:]]+):server\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsTransferForSftpServer
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_transfer_for_sftp_servers(context)
    process_payload Gdas::Assets::Aws::TransferForSftp::Servers::DerivedProcessor.new, context
  end
end
# :nocov:
