# frozen_string_literal: true

require 'gdas/assets/aws/virtual_private_cloud/context'

module Gdas::Assets::Aws::VirtualPrivateCloud
  module VpcEndpoints
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'vpc_endpoint'
      end

      # Resource ID format: arn:aws:ec2:us-west-2:012345678910:vpc-endpoint/misc
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Virtual Private Cloud',
        resource_id_pattern: /(.*?):ec2:([^:]+):([[:digit:]]+):vpc-endpoint\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsVirtualPrivateCloudVpcEndpoint
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_virtual_private_cloud_vpc_endpoints(context)
    process_payload Gdas::Assets::Aws::VirtualPrivateCloud::VpcEndpoints::DerivedProcessor.new, context
  end
end
# :nocov:
