# frozen_string_literal: true

require 'gdas/assets/aws/virtual_private_cloud/context'

module Gdas::Assets::Aws::VirtualPrivateCloud
  module VpnConnections
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'vpn_connection'
      end

      # Resource ID format: vpn-misc
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon Virtual Private Cloud',
        resource_id_pattern: /vpn-.*/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsVirtualPrivateCloudVpnConnection
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_virtual_private_cloud_vpn_connections(context)
    process_payload Gdas::Assets::Aws::VirtualPrivateCloud::VpnConnections::DerivedProcessor.new, context
  end
end
# :nocov:
