# frozen_string_literal: true

require 'gdas/assets/aws/waf/context'

module Gdas::Assets::Aws::Waf
  module Rules
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'rule'
      end

      # Resource ID format: arn:aws:waf-regional:region:account-id:webacl+rule_group+rule/id
      #                  OR arn:aws:waf::account-id:webacl+rule/ids
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS WAF',
        resource_id_pattern: /(.*?):(waf|waf-regional):([^:]*):([[:digit:]]+):webacl(.*?\+.*?)rule\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsWafRule
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_waf_rules(context)
    process_payload Gdas::Assets::Aws::Waf::Rules::DerivedProcessor.new, context
  end
end
# :nocov:
