# frozen_string_literal: true

require 'gdas/assets/aws/waf/context'

module Gdas::Assets::Aws::Waf
  module Webacls
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'webacl'
      end

      # Resource ID format:
      # Old: arn:aws:waf-regional:region:account-id:webacl/acl-uuid
      # New: arn:aws:wafv2:region:account:scope/webacl/name/ID
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'AWS WAF',
        resource_id_pattern: /(.*?):(waf|waf-regional|wafv2):([^:]*):([[:digit:]]+):([^:]+\/)?webacl\/(.*)/,
        format: 1
      )
    end

    class DerivedProcessor < ::Gdas::Processing::Aws::AwsDerivedAssetProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      model ::AwsWafWebacl
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_waf_webacls(context)
    process_payload Gdas::Assets::Aws::Waf::Webacls::DerivedProcessor.new, context
  end
end
# :nocov:
