# frozen_string_literal: true

require 'gdas/assets/aws/work_spaces/context'

module Gdas::Assets::Aws::WorkSpace
  module WorkSpaces
    class DerivedCollector < ::Gdas::Collection::AwsDerivedCollector
      include Context

      def self.asset
        'work_space'
      end

      # Resource ID format: arn:aws:workspaces:ap-southeast-2:786436275750:workspace/ws-9x3hnwmpf
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: 'Amazon WorkSpaces',
        resource_id_pattern: /(.*?):workspaces:([^:]+):([[:digit:]]+):workspace\/ws-(.*)/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Aws::AwsLifetimeProcessor
      register(
        source: AWS_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        :workspace_id
      )

      class << self
        def primary_identifier
          :workspace_id
        end
      end


      def get_identifier(resource_id)
        resource_id.split('/').last
      end

      model ::AwsWorkspace
    end
  end
end

