# frozen_string_literal: true

require 'gdas/assets/azure/cache/context'

module Gdas::Assets::Azure::Cache
  module Redises
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'redis'
      end

      # Resource ID format:
      # /subscriptions/700f3a5c-8c56-44b9-aa1d-fcfb1493aa4b/resourceGroups/ChtDev/providers/Microsoft.Cache/Redis/testredshirtcache
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.cache'],
        resource_id_pattern: /.*\/providers\/microsoft\.cache\/redis\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      REDIS_CACHE_STR = '/redis/'
      REDIS_CACHE_TYPE_STR = '/providers/microsoft.cache'

      def static_resource_id_strs
        [REDIS_CACHE_TYPE_STR, REDIS_CACHE_STR]
      end

      model ::AzureRedisCache
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_cache_redises(context)
    process_payload Gdas::Assets::Azure::Cache::Redis::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
