# frozen_string_literal: true

require 'gdas/assets/azure/cdn/context'

module Gdas::Assets::Azure::Cdn
  module Profiles
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'profile'
      end

      # Resource ID format:
      # /subscriptions/3ad22ffb-6fbc-4efa-9bbc-c6755b428af8/resourceGroups/FrontDoor/providers/Microsoft.Cdn/profiles/cdn002
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.cdn'],
        resource_id_pattern: /^.*\/providers\/microsoft\.cdn\/profiles\/[a-z0-9\-]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      CDN_PROFILE_STR = '/providers/microsoft.cdn/profiles/'

      def static_resource_id_strs
        [CDN_PROFILE_STR]
      end

      model ::AzureCdnProfile
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_cdn_profiles(context)
    process_payload Gdas::Assets::Azure::Cdn::Profiles::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
