# frozen_string_literal: true

require 'gdas/assets/azure/compute/context'

module Gdas::Assets::Azure::Compute
  module ManagedDisks
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'managed_disk'
      end

      # Resource ID format:
      # /subscriptions/a7dd1936-77ab-4712-85c2-ca3b156a3649/resourceGroups/HEC44-PBA-WESTEUROPE-1/providers/Microsoft.Compute/disks/bd33235422
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.compute'],
        resource_id_pattern: /^.*\/providers\/microsoft\.compute\/disks\/[a-z0-9\-_]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      MANAGED_DISK_STR = '/providers/microsoft.compute/disks/'

      def static_resource_id_strs
        [MANAGED_DISK_STR]
      end

      model ::AzureManagedDisk
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_managed_disks(context)
    process_payload Gdas::Assets::Azure::Compute::ManagedDisks::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
