# frozen_string_literal: true

require 'gdas/assets/azure/compute/context'

module Gdas::Assets::Azure::Compute
  module Snapshots
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'snapshot'
      end

      # Resource ID format:
      # /subscriptions/0808aa74-c021-4c7a-b435-3a6335033a7a/resourceGroups/PRODUCTION/providers/Microsoft.Compute/snapshots/orca-automatically-created-snapshot-9H44CPYo
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.compute'],
        resource_id_pattern: /^.*\/providers\/microsoft\.compute\/snapshots\/[a-z0-9\-_.]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SNAPSHOT_STR = '/providers/microsoft.compute/snapshots/'

      def static_resource_id_strs
        [SNAPSHOT_STR]
      end

      model ::AzureSnapshot
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_snapshots(context)
    process_payload Gdas::Assets::Azure::Compute::Snapshots::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
