# frozen_string_literal: true

require 'gdas/assets/azure/compute/context'

module Gdas::Assets::Azure::Compute
  module VmScaleSets
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'vm_scale_set'
      end

      # Resource ID format:
      # /subscriptions/700f3a5c-8c56-44b9-aa1d-fcfb1493aa4b/resourcegroups/liam-scale-set-test/providers/microsoft.compute/virtualmachinescalesets/eng32500-ldouglass-test
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.compute'],
        resource_id_pattern: /^.*\/providers\/microsoft\.compute\/virtualmachinescalesets\/[a-z0-9\-_]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SUBSCRIPTIONS_STR = '/subscriptions/'
      RESOURCE_GROUPS_STR = '/resourcegroups/'
      COMPUTE_TYPE_STR = '/providers/microsoft.compute'
      VIRTUAL_MACHINES_STR = '/virtualmachines/'
      SCALE_SET_STR = '/virtualmachinescalesets/'

      def static_resource_id_strs
        [SUBSCRIPTIONS_STR, RESOURCE_GROUPS_STR, COMPUTE_TYPE_STR, VIRTUAL_MACHINES_STR, SCALE_SET_STR]
      end

      model ::AzureVmScaleSet
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_vm_scale_sets(context)
    process_payload Gdas::Assets::Azure::Compute::VmScaleSets::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
