# frozen_string_literal: true

require 'gdas/assets/azure/compute/context'

module Gdas::Assets::Azure::Compute
  module Vms
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'vm'
      end

      # Resource ID format:
      # /subscriptions/700f3a5c-8c56-44b9-aa1d-fcfb1493aa4b/resourcegroups/trn-grp/providers/microsoft.compute/virtualmachines/demoecomm
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.compute'],
        resource_id_pattern: /^.*\/microsoft\.(classic)?compute\/virtualmachines\/[a-z0-9\-_]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      asset_identifiers(
        { dso: :resource_id, db: :instance_id }
      )

      COMPUTE_TYPE_STR = '/providers/microsoft.compute'
      CLASSIC_COMPUTE_TYPE_STR = '/providers/microsoft.classiccompute'
      VIRTUAL_MACHINES_STR = '/virtualmachines/'

      def static_resource_id_strs
        [COMPUTE_TYPE_STR, CLASSIC_COMPUTE_TYPE_STR, VIRTUAL_MACHINES_STR]
      end

      model ::AzureVm
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_vms(context)
    process_payload Gdas::Assets::Azure::Compute::Vms::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
