# frozen_string_literal: true

require 'gdas/assets/azure/databricks/context'

module Gdas::Assets::Azure::Databricks
  module Workspaces
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'workspace'
      end

      # Resource ID format:
      # /subscriptions/008767c7-ec6a-401e-b62c-eaa2258d1b2a/resourceGroups/az-prod-germanywestcentral/providers/Microsoft.Databricks/workspaces/cx-aiml-prod-dewc
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.databricks'],
        resource_id_pattern: /^.*\/providers\/microsoft\.databricks\/workspaces\/[a-z0-9\-_]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      AZURE_DATABRICKS_WORKSPACE_STR = '/providers/microsoft.databricks/workspaces'

      def static_resource_id_strs
        [AZURE_DATABRICKS_WORKSPACE_STR]
      end

      model ::AzureDatabricksWorkspace
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_databricks_workspaces(context)
    process_payload Gdas::Assets::Azure::Databricks::Workspaces::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
