# frozen_string_literal: true

require 'gdas/assets/azure/devices/context'

module Gdas::Assets::Azure::Devices
  module IotHubs
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'iot_hub'
      end

      # Resource ID format:
      # /SUBSCRIPTIONS/AA849650-19B0-4D26-B0A8-84AE63C18E04/RESOURCEGROUPS/SAPIOTPRESALES/PROVIDERS/MICROSOFT.DEVICES/IOTHUBS/SAPPRESALESIOTHUB01
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.devices'],
        resource_id_pattern: /^.*\/providers\/microsoft\.devices\/iothubs\/[a-z0-9\-]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      IOT_HUB_STR = '/providers/microsoft.devices/iothubs/'

      def static_resource_id_strs
        [IOT_HUB_STR]
      end

      model ::AzureIotHub
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_iot_hubs(context)
    process_payload Gdas::Assets::Azure::Devices::IotHubs::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
