# frozen_string_literal: true

require 'gdas/assets/azure/document_db/context'

module Gdas::Assets::Azure::DocumentDb
  module DocumentDbs
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'document_db'
      end

      # Resource ID format:
      # /subscriptions/151f9055-7a93-4bbb-8de3-e8af62caa854/resourcegroups/chtdev/providers/microsoft.documentdb/databaseaccounts/matt-cosmos-test-kv
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.documentdb'],
        resource_id_pattern: /^.*\/providers\/microsoft\.documentdb\/databaseaccounts\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      DOCUMENT_DB_STR = '/providers/microsoft.documentdb/databaseaccounts/'

      def static_resource_id_strs
        [DOCUMENT_DB_STR]
      end

      model ::AzureDocumentDb
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_document_dbs(context)
    process_payload Gdas::Assets::Azure::DocumentDb::DocumentDbs::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
