# frozen_string_literal: true

require 'gdas/assets/azure/event_hub/context'

module Gdas::Assets::Azure::EventHub
  module Namespaces
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'namespace'
      end

      # Resource ID format:
      # /subscriptions/151f9055-7a93-4bbb-8de3-e8af62caa854/resourcegroups/lw/providers/microsoft.eventhub/namespaces/lacework
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.eventhub'],
        resource_id_pattern: /^.*\/providers\/microsoft\.eventhub\/namespaces\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      EVENT_HUB_NAMESPACE_STR = '/providers/microsoft.eventhub/namespaces/'

      def static_resource_id_strs
        [EVENT_HUB_NAMESPACE_STR]
      end

      model ::AzureEventHubNamespace
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_event_hub_namespaces(context)
    process_payload Gdas::Assets::Azure::EventHub::Namespaces::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
