# frozen_string_literal: true

require 'gdas/assets/azure/hd_insight/context'

module Gdas::Assets::Azure::HdInsight
  module Clusters
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'cluster'
      end

      # Resource ID format:
      # /subscriptions/f8bcef07-4fe7-49c1-8a27-547a86238930/resourceGroups/shoot--ome--cic-rao-prod-eu/providers/Microsoft.HDInsight/clusters/cic-rao-prod-eu-hdinsight
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.hdinsight'],
        resource_id_pattern: /.*\/providers\/microsoft\.hdinsight\/clusters\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      HD_INSIGHT_CLUSTER_STR = '/providers/microsoft.hdinsight/clusters/'

      def static_resource_id_strs
        [HD_INSIGHT_CLUSTER_STR]
      end

      model ::AzureHdInsightCluster
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_hd_insight_clusters(context)
    process_payload Gdas::Assets::Azure::HdInsight::Clusters::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
