# frozen_string_literal: true

require 'gdas/assets/azure/insights/context'

module Gdas::Assets::Azure::Insights
  module AppInsights
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'app_insight'
      end

      # Resource ID format:
      # /subscriptions/394fab31-b1a3-45fa-b9a9-c3d907776a11/resourcegroups/cookies/providers/microsoft.insights/components/scanworker disk gt 80pct
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.insights'],
        resource_id_pattern: /.*\/providers\/microsoft\.insights\/components\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      APP_INSIGHT_STR = '/providers/microsoft.insights/components/'

      def static_resource_id_strs
        [APP_INSIGHT_STR]
      end

      model ::AzureAppInsight
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_app_insights(context)
    process_payload Gdas::Assets::Azure::Insights::AppInsights::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
