# frozen_string_literal: true

require 'gdas/assets/azure/key_vault/context'

module Gdas::Assets::Azure::KeyVault
  module Vaults
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'vault'
      end

      # Resource ID format:
      # /subscriptions/368c3b2d-9137-4a30-91ca-a93ddf92b46d/resourceGroups/modelt-tg16test/providers/Microsoft.KeyVault/vaults/modelt-tg16test-vault
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.keyvault'],
        resource_id_pattern: /^.*\/providers\/microsoft\.keyvault\/vaults\/[a-z0-9\-]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      KEY_VAULT_STR = '/providers/microsoft.keyvault/vaults/'

      def static_resource_id_strs
        [KEY_VAULT_STR]
      end

      model ::AzureKeyVault
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_key_vaults(context)
    process_payload Gdas::Assets::Azure::KeyVault::Vaults::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
