# frozen_string_literal: true

require 'gdas/assets/azure/mysql/context'

module Gdas::Assets::Azure::MySQL
  module Servers
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'server'
      end

      # Resource ID format:
      # /subscriptions/151F9055-7A93-4BBB-8DE3-E8AF62CAA854/resourceGroups/ChtDev/providers/Microsoft.DBforMySQL/servers/abbycistestmysql
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.dbformysql'],
        resource_id_pattern: /.*\/providers\/microsoft\.dbformysql\/servers\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      AZURE_MYSQL_SERVER_STR = '/providers/microsoft.dbformysql/servers'

      def static_resource_id_strs
        [AZURE_MYSQL_SERVER_STR]
      end

      model ::AzureMysqlServer
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_mysql_servers(context)
    process_payload Gdas::Assets::Azure::MySQL::Servers::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
