# frozen_string_literal: true

require 'gdas/assets/azure/operational_insights/context'

module Gdas::Assets::Azure::OperationalInsights
  module LogAnalyticsWorkspaces
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'log_analytics_workspace'
      end

      # Resource ID format:
      # /subscriptions/38553983-b252-47ec-879d-5299151a8434/resourcegroups/defaultresourcegroup-eus/providers/microsoft.operationalinsights/workspaces/defaultworkspace-38553983-b252-47ec-879d-5299151a8434-eus
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.operationalinsights'],
        resource_id_pattern: /^.*\/providers\/microsoft\.operationalinsights\/workspaces\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      LOG_ANALYTICS_WORKSPACE_STR = '/providers/microsoft.operationalinsights/workspaces/'

      def static_resource_id_strs
        [LOG_ANALYTICS_WORKSPACE_STR]
      end

      model ::AzureLogAnalyticsWorkspace
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_log_analytics_workspaces(context)
    process_payload Gdas::Assets::Azure::OperationalInsights::LogAnalyticsWorkspaces::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
