# frozen_string_literal: true

require 'gdas/assets/azure/recovery_service/context'

module Gdas::Assets::Azure::RecoveryService
  module Vaults
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'vault'
      end

      # Resource ID format:
      # /subscriptions/700f3a5c-8c56-44b9-aa1d-fcfb1493aa4b/resourceGroups/lucas/providers/Microsoft.RecoveryServices/vaults/vault337
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.recoveryservices'],
        resource_id_pattern: /.*\/providers\/microsoft\.recoveryservices\/vaults\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      RECOVERY_SERVICES_VAULT_STR = '/providers/microsoft.recoveryservices/vaults/'

      def static_resource_id_strs
        [RECOVERY_SERVICES_VAULT_STR]
      end

      model ::AzureRecoveryServicesVault
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_recovery_services_vaults(context)
    process_payload Gdas::Assets::Azure::RecoveryService::Vaults::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
