# frozen_string_literal: true

require 'gdas/assets/azure/search/context'

module Gdas::Assets::Azure::Search
  module Services
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'service'
      end

      # Resource ID format:
      # /subscriptions/bef2b96a-8194-40da-b5be-d91042bfcbf1/resourceGroups/ain_prod_eu20/providers/Microsoft.Search/searchServices/acsearch-eu20preview
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.search'],
        resource_id_pattern: /.*\/providers\/microsoft\.search\/searchservices\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SEARCH_SERVICE_STR = '/providers/microsoft.search/searchservices/'

      def static_resource_id_strs
        [SEARCH_SERVICE_STR]
      end

      model ::AzureSearchService
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_search_services(context)
    process_payload Gdas::Assets::Azure::Search::Services::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
