# frozen_string_literal: true

require 'gdas/assets/azure/service_bus/context'

module Gdas::Assets::Azure::ServiceBus
  module Namespaces
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'namespace'
      end

      # Resource ID format:
      # /subscriptions/151f9055-7a93-4bbb-8de3-e8af62caa854/resourceGroups/Default-ServiceBus-EastUS/providers/Microsoft.ServiceBus/namespaces/test1114
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.servicebus'],
        resource_id_pattern: /.*\/providers\/microsoft\.servicebus\/namespaces\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SERVICE_BUS_NAMESPACE_STR = '/providers/microsoft.servicebus/namespaces/'

      def static_resource_id_strs
        [SERVICE_BUS_NAMESPACE_STR]
      end

      model ::AzureServiceBusNamespace
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_service_bus_namespaces(context)
    process_payload Gdas::Assets::Azure::ServiceBus::Namespaces::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
