# frozen_string_literal: true

require 'gdas/assets/azure/sql/context'

module Gdas::Assets::Azure::SQL
  module Databases
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'database'
      end

      def self.gdas_artifact_name
        'azure_sql_databases'
      end

      # Resource ID format:
      # /subscriptions/151f9055-7a93-4bbb-8de3-e8af62caa854/resourcegroups/default-sql-eastus/providers/microsoft.sql/servers/xufwesovdx/databases/jeff-test-1
      # Product name and resource id are the same as Sql Warehouses, so they are separated into different xform artifacts
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.sql'],
        resource_id_pattern: /^.*\/providers\/microsoft\.sql\/servers\/[^\/]*\/databases\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SQL_DATABASE_STR = '/databases/'
      SQL_SERVER_STR = '/providers/microsoft.sql/servers/'

      def static_resource_id_strs
        [SQL_DATABASE_STR, SQL_SERVER_STR]
      end

      model ::AzureSqlDatabase
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_sql_databases(context)
    process_payload Gdas::Assets::Azure::SQL::Databases::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
