# frozen_string_literal: true

require 'gdas/assets/azure/sql/context'

module Gdas::Assets::Azure::SQL
  module ManagedInstances
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'managed_instance'
      end

      # Resource ID format:
      # /subscriptions/8C44EF06-ED8A-4759-9941-A8D77C09B881/resourceGroups/rg-aquilasqlmi-ctwmon/providers/Microsoft.Sql/managedInstances/azweaquilasqlmi01
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.sql'],
        resource_id_pattern: /^.*\/providers\/microsoft\.sql\/managedinstances\/[a-zA-Z0-9\-]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SQL_MANAGED_INSTANCE_STR = '/providers/microsoft.sql/managedinstances/'

      def static_resource_id_strs
        [SQL_MANAGED_INSTANCE_STR]
      end

      model ::AzureSqlManagedInstance
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_sql_managed_instances(context)
    process_payload Gdas::Assets::Azure::SQL::ManagedInstances::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
