# frozen_string_literal: true

require 'gdas/assets/azure/sql/context'

module Gdas::Assets::Azure::SQL
  module Servers
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'server'
      end

      # Resource ID format:
      # /subscriptions/151F9055-7A93-4BBB-8DE3-E8AF62CAA854/resourceGroups/Default-SQL-EastUS/providers/Microsoft.Sql/servers/xufwesovdx
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.sql'],
        resource_id_pattern: /^.*\/providers\/microsoft\.sql\/servers\/[a-zA-Z0-9\-]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SQL_SERVER_STR = '/providers/microsoft.sql/servers/'

      def static_resource_id_strs
        [SQL_SERVER_STR]
      end

      model ::AzureSqlServer
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_sql_servers(context)
    process_payload Gdas::Assets::Azure::SQL::Servers::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
