# frozen_string_literal: true

require 'gdas/assets/azure/sql/context'

module Gdas::Assets::Azure::SQL
  module Warehouses
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'warehouse'
      end

      def self.gdas_artifact_name
        'azure_sql_data_warehouses'
      end

      # Resource ID format:
      # /subscriptions/151F9055-7A93-4BBB-8DE3-E8AF62CAA854/resourceGroups/AlansGroup/providers/Microsoft.Sql/servers/alansdatabaseserver/databases/DansSQLDataWarehouse
      # Product name and resource id are the same as Sql Databases, so they are separated into different xform artifacts
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.sql'],
        resource_id_pattern: /^.*\/providers\/microsoft\.sql\/servers\/[^\/]*\/databases\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SQL_DATABASE_STR = '/databases/'
      SQL_SERVER_STR = '/providers/microsoft.sql/servers/'

      def static_resource_id_strs
        [SQL_DATABASE_STR, SQL_SERVER_STR]
      end

      model ::AzureSqlDataWarehouse
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_sql_data_warehouses(context)
    process_payload Gdas::Assets::Azure::SQL::Warehouses::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
