# frozen_string_literal: true

require 'gdas/assets/azure/storage/context'

module Gdas::Assets::Azure::Storage
  module Storages
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'storage'
      end

      # Resource ID format:
      # /subscriptions/38553983-b252-47ec-879d-5299151a8434/resourcegroups/mayaritest/providers/microsoft.storage/storageaccounts/mayaritestdiag232
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['storage', 'microsoft.storage', 'microsoft.classicstorage'],
        resource_id_pattern: /^.*\/providers\/microsoft\.(classic)?storage\/storageaccounts\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      STORAGE_TYPE_STR = '/providers/microsoft.storage'
      CLASSIC_STORAGE_TYPE_STR = '/providers/microsoft.classicstorage'
      STORAGE_STR = '/storageaccounts/'

      def static_resource_id_strs
        [STORAGE_TYPE_STR, CLASSIC_STORAGE_TYPE_STR, STORAGE_STR]
      end

      model ::AzureStorage
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_storages(context)
    process_payload Gdas::Assets::Azure::Storage::Storages::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
