# frozen_string_literal: true

require 'gdas/assets/azure/storsimple/context'

module Gdas::Assets::Azure::Storsimple
  module DeviceManagers
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'device_manager'
      end

      # Resource ID format:
      # /subscriptions/43f36706-79c0-4f23-9853-a28102e5ef94/resourcegroups/cisservice-2eh4gyrcy4fcv6gfxs74cadx57z44bp7g23vbd3obd3hbea5icna-west-europe/providers/microsoft.storsimple/managers/prs-storsimple
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.storsimple'],
        resource_id_pattern: /^.*\/providers\/microsoft\.storsimple\/managers\/[a-zA-Z0-9\-]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      STOR_SIMPLE_DEVICE_MANAGER_STR = '/providers/microsoft.storsimple/managers/'

      def static_resource_id_strs
        [STOR_SIMPLE_DEVICE_MANAGER_STR]
      end

      model ::AzureStorSimpleDeviceManager
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_storsimple_device_managers(context)
    process_payload Gdas::Assets::Azure::Storsimple::DeviceManagers::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
