# frozen_string_literal: true

require 'gdas/assets/azure/virtual_networks/context'

module Gdas::Assets::Azure::VirtualNetwork
  module ApplicationGateways
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'application_gateway'
      end

      # Resource ID format:
      # /subscriptions/86b0d4f8-1c81-4fd2-bbb1-75b952e7f48a/resourceGroups/rg-tssdevstage-amer/providers/Microsoft.Network/applicationGateways/amerappgwtssdevstage
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.network'],
        resource_id_pattern: /.*\/providers\/microsoft\.network\/applicationgateways\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      APPLICATION_GATEWAY_STR = '/providers/microsoft.network/applicationgateways/'

      def static_resource_id_strs
        [APPLICATION_GATEWAY_STR]
      end

      model ::AzureApplicationGateway
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_virtual_network_application_gateways(context)
    process_payload Gdas::Assets::Azure::VirtualNetwork::ApplicationGateways::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
