# frozen_string_literal: true

require 'gdas/assets/azure/virtual_networks/context'

module Gdas::Assets::Azure::VirtualNetwork
  module Circuits
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'circuit'
      end

      # Resource ID format:
      # /subscriptions/151f9055-7a93-4bbb-8de3-e8af62caa854/resourcegroups/bulletproof-aus/providers/microsoft.network/expressroutecircuits/eatest-azmh-er-01
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['expressroute', 'microsoft.network'],
        resource_id_pattern: /^.*\/providers\/microsoft\.network\/expressroutecircuits\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      EXPRESS_ROUTE_CIRCUIT_STR = '/providers/microsoft.network/expressroutecircuits/'

      def static_resource_id_strs
        [EXPRESS_ROUTE_CIRCUIT_STR]
      end

      model ::AzureExpressRouteCircuit
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_express_route_circuits(context)
    process_payload Gdas::Assets::Azure::VirtualNetwork::Circuits::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
