# frozen_string_literal: true

require 'gdas/assets/azure/virtual_networks/context'

module Gdas::Assets::Azure::VirtualNetwork
  module Gateways
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'gateway'
      end

      # Resource ID format:
      # /subscriptions/4cd5048a-a7b9-471c-b814-86631786c3c7/resourceGroups/cbs-dr-core-resources/providers/Microsoft.Network/virtualNetworkGateways/cbs-dr-p2s-gw1-auseast
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.network', 'virtual network'],
        resource_id_pattern: /.*\/providers\/microsoft\.network\/virtualnetworkgateways\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SUBSCRIPTIONS_STR = '/subscriptions/'
      NETWORK_TYPE_STR = '/providers/microsoft.network'
      RESOURCE_GROUPS_STR = '/resourcegroups/'
      VIRTUAL_NETWORK_GATEWAY_STR = '/virtualnetworkgateways/'

      def static_resource_id_strs
        [SUBSCRIPTIONS_STR, NETWORK_TYPE_STR, RESOURCE_GROUPS_STR, VIRTUAL_NETWORK_GATEWAY_STR]
      end

      model ::AzureVirtualNetworkGateway
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_virtual_network_gateways(context)
    process_payload Gdas::Assets::Azure::VirtualNetwork::Gateways::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
