# frozen_string_literal: true

require 'gdas/assets/azure/virtual_networks/context'

module Gdas::Assets::Azure::VirtualNetwork
  module IpAddresses
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'ip_address'
      end

      # Resource ID format:
      # /subscriptions/805a81a5-cc3f-4f8c-be5a-a5497e2ed239/resourceGroups/shoot--hc-dev--aba320-orc/providers/Microsoft.Network/publicIPAddresses/shoot--hc-dev--aba320-orc-a04378f2e38af4a73b25d40f6c69d48f
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.network'],
        resource_id_pattern: /^.*\/providers\/microsoft\.network\/publicipaddresses\/[a-z0-9\-\._]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      NETWORK_TYPE_STR = '/providers/microsoft.network'
      IP_ADDRESSES_STR = '/publicipaddresses/'

      def static_resource_id_strs
        [NETWORK_TYPE_STR, IP_ADDRESSES_STR]
      end

      model ::AzureIpAddress
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_virtual_network_ip_addresses(context)
    process_payload Gdas::Assets::Azure::VirtualNetwork::IpAddresses::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
