# frozen_string_literal: true

require 'gdas/assets/azure/virtual_networks/context'

module Gdas::Assets::Azure::VirtualNetwork
  module SecurityGroups
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'security_group'
      end

      # Resource ID format:
      # /subscriptions/16AD257E-6EC4-4608-A88D-545B99C42AA1/resourceGroups/C9DPW0B-CORSAIRCO1-P1/providers/Microsoft.Network/NETWORKSECURITYGROUPS/C9DPW0B-CORSAIRCO1-P1
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.network', 'microsoft.classicnetwork'],
        resource_id_pattern: /^.*\/providers\/microsoft\.(classic)?network\/networksecuritygroups\/[a-z0-9\-\._]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      SECURITY_GROUPS_STR = '/networksecuritygroups/'
      NETWORK_TYPE_STR = '/providers/microsoft.network'
      CLASSIC_NETWORK_TYPE_STR = '/providers/microsoft.classicnetwork'

      def static_resource_id_strs
        [NETWORK_TYPE_STR, CLASSIC_NETWORK_TYPE_STR, SECURITY_GROUPS_STR]
      end

      model ::AzureSecurityGroup
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_virtual_network_security_groups(context)
    process_payload Gdas::Assets::Azure::VirtualNetwork::SecurityGroups::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
