# frozen_string_literal: true

require 'gdas/assets/azure/web/context'

module Gdas::Assets::Azure::Web
  module AppServicePlans
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'app_service_plan'
      end

      # Resource ID format:
      # /subscriptions/151f9055-7a93-4bbb-8de3-e8af62caa854/resourcegroups/chtdev/providers/microsoft.web/serverfarms/inuseappserviceplan
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.web'],
        resource_id_pattern: /^(?!.*unused_pool_for_)(?!.*frontend_pool_for_).*\/providers\/microsoft\.web\/serverfarms\/[^\/]*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      APP_SERVICE_PLAN_TYPE_STR = '/providers/microsoft.web/serverfarms'

      def static_resource_id_strs
        [APP_SERVICE_PLAN_TYPE_STR]
      end

      model ::AzureAppServicePlan
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_app_service_plans(context)
    process_payload Gdas::Assets::Azure::Web::AppServicePlans::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
