# frozen_string_literal: true

require 'gdas/assets/azure/web/context'

module Gdas::Assets::Azure::Web
  module AppServices
    class DerivedCollector < ::Gdas::Collection::AzureDerivedCollector
      include Context

      def self.asset
        'app_service'
      end

      # Resource ID format:
      # /subscriptions/700f3a5c-8c56-44b9-aa1d-fcfb1493aa4b/resourcegroups/chtdev/providers/microsoft.web/sites/testdocker123
      register_derived_collector(
        service: service,
        asset: asset,
        product_name: ['microsoft.web'],
        resource_id_pattern: /^.*\/providers\/microsoft\.web\/sites\/[^\/].*$/,
        format: 1
      )
    end

    class DerivedLifetimeProcessor < ::Gdas::Processing::Azure::AzureLifetimeProcessor
      register(
        source: AZURE_GDAS_BILL,
        service: DerivedCollector.service,
        asset: DerivedCollector.asset,
        format: 1
      )

      APP_SERVICE_STR = '/providers/microsoft.web/sites/'


      def static_resource_id_strs
        [APP_SERVICE_STR]
      end

      model ::AzureAppService
    end
  end
end

# :nocov: Development only
if ImportRegistry.resolve('runtime').sandbox?
  def process_azure_app_services(context)
    process_payload Gdas::Assets::Azure::Web::AppServices::DerivedLifetimeProcessor.new, context
  end
end
# :nocov:
