# frozen_string_literal: true

module Gdas::Assets::GenericDerivedAssetScanner::CsvStream
  module CsvAnalyzerUtilities
    # Create a lookup to get the numerical index of a given column name.
    # This allows the lookup of a value with this structure:
    #   value = row[column_index_lookup['ColumnName']]
    # Params:
    # - +header_row+:: Array of strings, containing the column headers.
    # Returns:
    # - Hash of the format:
    #   {
    #     "column_header" => 0, # index in the array
    #     "another_column_header" => 1
    #   }
    def build_column_label_index(header_row)
      header_row.each_with_object({}).with_index do |(column_label, hash), index|
        hash[column_label] = index
      end
    end
  end
end
