# frozen_string_literal: true

module Gdas::Collection
  # Derived Asset Collection Task is the task definition used for the Generic Derived Asset Scanner. It is
  # similar to a StreamingTask, but it allows setting the +ch_account_id+ on each payload from the collector.
  # This is needed because the scanner runs once per billing account, but processing expects one job
  # per account. The collector fans out to one job per customer/account/asset type using this task.
  class DerivedAssetCollectionTask < CloudHealth::Collection::Task
    def process_derived_results(ch_account_id, payload)
      raise ::Platform::NonRetryableError, original_exception: 'No account provided for DerivedAssetCollectionTask.' if ch_account_id.blank?

      # Override the account ID with the one specified. This allows a fanout to multiple accounts
      # after scanning on only the billing account.
      # Note that the customer ID can't be changed. This helps protect from cross-tenant issues.
      @context[:ch_account_id] = ch_account_id
      @options[:ch_account_id] = ch_account_id
      dispatch_payload payload
    end

    private

    set_callback :execute, :before, :enable_observation

    def enable_observation
      @collector_instance.add_observer self, :process_derived_results
    end
  end
end
