# frozen_string_literal: true

require 'cht-lib-fabric'
require 'cht-lib-scheduler'

module Gdas
  module Consumers
    autoload :GenericDerivedAssetsConsumer, 'gdas/consumers/generic_derived_assets'
  end

  module Workers
    autoload :AwsGdasWorker, 'gdas/workers/generic_derived_assets'
    autoload :AzureGdasWorker, 'gdas/workers/generic_derived_assets'
  end
end

::Karafka::App.consumer_groups.draw do
  # Listen to all topics if running locally
  all_topics = ENV['RACK_ENV'] == 'test' || ENV['SANDBOX'] == '1'

  if ENV['GDAS_CLOUD'] == ::Gdas::Clouds::AwsCloudConfig::CLOUD_NAME || all_topics
    consumer_group :aws_generic_derived_asset_scanner do
      topic 'com.cloudhealthtech.superxform.gdas.collection' do
        consumer ::Gdas::Consumers::GenericDerivedAssetsConsumer
        worker ::Gdas::Workers::AwsGdasWorker
      end
      topic 'com.cloudhealthtech.superxform.gdas.ecs.collection' do
        consumer ::Gdas::Consumers::GenericDerivedAssetsConsumer
        worker ::Gdas::Workers::AwsGdasWorker
      end
    end
  end

  if ENV['GDAS_CLOUD'] == ::Gdas::Clouds::AzureCloudConfig::CLOUD_NAME || all_topics
    consumer_group :azure_generic_derived_asset_scanner do
      topic 'com.cloudhealthtech.superxform.gdas.azure.collection' do
        consumer ::Gdas::Consumers::GenericDerivedAssetsConsumer
        worker ::Gdas::Workers::AzureGdasWorker
      end
    end
  end
end
