
module Gdas::Processing
  module AssetCaches
    extend ::ActiveSupport::Concern

    included do
      # Lookup an +AwsAccount+ +id+ by +AwsAccount+ +owner_id+ for the current customer.
      def aws_account_id_lookup
        ::AwsAccount
          .select([:id, :owner_id])
          .where(customer_id: @customer_id)
          .for_enumeration_reading
          .inject({}) { |acc, o| acc[o.owner_id] = o.id; acc }
        # ActiveRecord::OnDemand::FastEnumeration doesn't support +each_with_object+ yet.
      end
      memoize :aws_account_id_lookup

      # Lookup an +AzureSubscription+ +id+ by +AzureSubscription+ +azure_id+ for the current customer.
      def azure_account_id_lookup
        ::AzureSubscription
          .select([:id, :azure_id])
          .where(customer_id: @customer_id)
          .for_enumeration_reading
          .inject({}) { |acc, o| acc[o.azure_id] = o.id; acc }
      end
      memoize :azure_account_id_lookup
    end
  end
end
