# frozen_string_literal: true


module Gdas::Workers
  # Required to allow a new set of +sidekiq_options+ unique to G-DAS processing.
  class AwsProcessingAssetsWorker < ::CloudHealth::Processing::Workers::ProcessingAssetsWorker
    sidekiq_options queue: :processing_assets_aws_gdas, lock: :derived_processor_token_lock, on_conflict: :configurable_reschedule
  end

  class AzureProcessingAssetsWorker < ::CloudHealth::Processing::Workers::ProcessingAssetsWorker
    sidekiq_options queue: :processing_assets_azure_gdas, lock: :derived_processor_token_lock, on_conflict: :configurable_reschedule
  end

  class ProcessingAssetsWorker < ::CloudHealth::Processing::Workers::ProcessingAssetsWorker
    sidekiq_options lock: :derived_processor_token_lock, on_conflict: :configurable_reschedule

    CLOUD_TO_WORKER = {
      'aws' => AwsProcessingAssetsWorker,
      'azure' => AzureProcessingAssetsWorker
    }.freeze

    class << self
      # Custom version of Sidekiq's `perform_async` that lets us specify the queue dynamically
      def perform_async(*args)
        if args[1].nil? || args[1].first['cloud'].nil?
          ::ImportRegistry.resolve('logger').error("No cloud name provided in request. args: #{args}")
          ::ImportRegistry.resolve('alert').error('No cloud name provided in request', args: args)
          return
        end
        cloud = args[1].first['cloud']
        worker_class = CLOUD_TO_WORKER[cloud]
        if worker_class.nil?
          ::ImportRegistry.resolve('logger').error("Invalid cloud name provided in request. args: #{args}")
          ::ImportRegistry.resolve('alert').error('Invalid cloud name provided in request', args: args)
          return
        end

        queue = "processing_assets_#{cloud}_gdas"
        # add this to args so it can be preserved if job rescheduled
        args[1].first['queue'] = queue
        client_push('queue' => queue, 'class' => worker_class, 'args' => args)
      end
    end
  end

end
