require_relative 'aws_asset_base'

class AwsEc2ApplicationLoadBalancer < AwsAssetBase
  include ::Gdas::Helpers::ModelDefaultScopes

  belongs_to :customer
  belongs_to :aws_account
  belongs_to :aws_region
  belongs_to :aws_route53_hosted_zone
  belongs_to :aws_vpc
  has_and_belongs_to_many :aws_tags, join_table: :aws_ec2_application_load_balancers_aws_tags
  has_and_belongs_to_many :aws_availability_zones, join_table: :aws_ec2_application_load_balancers_aws_availability_zones
  has_and_belongs_to_many :aws_security_groups, join_table: :aws_ec2_application_load_balancers_aws_security_groups

  class << self
    def model_type_id
      ModelType::AWS_EC2_APPLICATION_LOAD_BALANCER
    end
  end

  def classic_name
    "Amazon EC2 Application Load Balancer #{resource_id}"
  end

  def arn
    resource_id
  end

  def crn
    [
      'crn:aws:ec2_application_load_balancer',
      customer_id,
      aws_account_id,
      id,
      created_at.to_i,
      ImportRegistry.resolve('cache.common_assets').region(aws_region_id).name,
      "ec2ApplicationLoadBalancerResourceId/#{resource_id}"
    ].join(':')
  end
end
