require_relative 'aws_asset_base'

class AwsRdsInstance < AwsAssetBase
  include ::Gdas::Helpers::ModelTermination
  include ::Gdas::Helpers::ModelDefaultScopes

  belongs_to :aws_availability_zone
  belongs_to :customer
  belongs_to :aws_account
  belongs_to :aws_region
  belongs_to :aws_instance_type
  has_many :aws_rds_snapshots
  has_and_belongs_to_many :aws_tags, join_table: :aws_rds_instances_aws_tags
  belongs_to :aws_rds_subnet_group
  has_one :aws_vpc, through: :aws_rds_subnet_group
  has_one :aws_instance_type_profile, through: :aws_instance_type
  has_and_belongs_to_many :aws_rds_security_groups, join_table: :aws_rds_instances_aws_rds_security_groups
  has_and_belongs_to_many :aws_security_groups, join_table: :aws_rds_instances_aws_security_groups

  terminated_attributes(
    state: {
      current: %w(available),
      final: 'deleting'
    }
  )

  class << self
    def model_type_id
      ModelType::AWS_RDS_INSTANCE
    end

    def audit_black_list
      [:last_restorable_time, :tags, :hourly_cost, :current_projected_cost, :current_reservation_pct]
    end
  end

  def classic_name
    "Amazon RDS instance #{instance_id}"
  end

  def crn
    [
      'crn:aws:rds',
      customer_id,
      aws_account_id,
      instance_id,
      id,
      ImportRegistry.resolve('cache.common_assets').region(aws_region_id).name,
      "instance/#{instance_id}"
    ].join(':')
  end
end
