# A Derived Asset has an updated_at_date, which makes DB access better
class GenericDerivedAsset < ActiveRecord::Base
  self.abstract_class = true

  class_attribute :account_attr, :tag_model, :tag_override_model, :tag_relation, :cloud

  before_save :set_updated_at_date

  # Used to help make a more efficient MySQL index.
  def set_updated_at_date
    # When an asset is moved from level 1.5 to level 2, the DB constraint on +updated_at_date+ must be
    # removed. This is because the +updated_at+ is set by Rails/ActiveRecord *after* all available callbacks
    # have been called, leaving no way to reliably calculate this field. Additionally, the field will not be
    # used for collected assets.

    unless self.has_attribute? :updated_at_date
      return
    end

    unless self.is_derived
      # For collected assets, +updated_at_date+ will always be +nil+.
      self.updated_at_date = nil
      return
    end

    # Only for derived assets:
    if self.updated_at
      self.updated_at_date = self.updated_at.to_date
    else
      self.updated_at_date = nil # This would cause a DB constraint error.
      raise 'updated_at must be set explicitly for generic derived assets.'
    end
  end
end
